OC.L10N.register(
    "spreed",
    {
    "a conversation" : "unha conversa",
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Participou nunha chamada con {user1}",
    "_%n guest_::_%n guests_" : ["%n convidado","%n convidados"],
    "You attended a call with {user1} and {user2}" : "Participou nunha chamada con {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Participou nunha chamada con {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Participou nunha chamada con {user1}, {user2}, {user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Participou nunha chamada con {user1}, {user2}, {user3}, {user4}e {user5}",
    "_%n other_::_%n others_" : ["outro","outros %n"],
    "{actor} invited you to {call}" : "{actor} convidouno á {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Foi convidado a unha <strong>conversa</strong> ou tivo unha <strong>chamada</strong>",
    "Other activities" : "Outras actividades",
    "Talk" : "Parladoiro",
    "Guest" : "Convidado",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Dámoslle a benvida a Parladoiro de Nextcloud!\nNesta conversa estará informado sobre as novas funcións dispoñíbeis no Parladoiro de Nextcloud.",
    "## New in Talk %s" : "## Novo en Parladoiro %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Agora poden empregarse Microsoft Edge e Safari para participar en chamadas de voz e vídeo",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- As conversas individuais son agora persistentes e xa non se poden converter en conversas grupais por accidente. Ademais, cando un dos participantes abandona a conversa, a conversa xa non se elimina automaticamente. Só se os dous participantes abandonan, a conversa é eliminada do servidor",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Agora pode notificar a todos os participantes publicando «@all» na parola",
    "- With the \"arrow-up\" key you can repost your last message" : "- Coa tecla «frecha arriba» pode responder a súa última mensaxe",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Parladoiro xa admite ordes, envíe «/help» como mensaxe da parola para ver se a administración desta instancia configurou algunha",
    "- With projects you can create quick links between conversations, files and other items" : "- Cos proxectos pode crear ligazóns rápidas entre conversas, ficheiros e outros elementos",
    "- You can now mention guests in the chat" : "- Agora pode mencionar convidados na parola",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- As conversas agora poden ter un ástrago. Isto permitirá aos moderadores unirse á parola e chamar xa para preparar a reunión, mentres que os usuarios e convidados teñen que agardar",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Agora pode responder directamente ás mensaxes fornecendolle aos demais usuarios máis contexto sobre o que trata a súa mensaxe",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- A busca de conversas e participantes agora tamén filtrarán as conversas existentes, polo que é moito máis doado atopar conversas anteriores",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Agora pode engadir grupos de usuarios personalizados ás conversas cando a aplicación de círculos está instalada",
    "- Check out the new grid and call view" : "- Bótelle unha ollada á nova grade e á vista de chamadas",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Agora pode enviar e arrastrar e soltar ficheiros directamente desde o seu dispositivo á parola",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Os ficheiros compartidos ábrense agora dentro da vista da parola coas aplicacións de visor",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Agora pode buscar parolas e mensaxes na busca unificada na barra superior",
    "- Spice up your messages with emojis from the emoji picker" : "- Adube as súas mensaxes con «emojis» do selector de «emoji»",
    "- You can now change your camera and microphone while being in a call" : "- Agora pode cambiar de cámara e de micrófono mentres está nunha chamada",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Déalle ás súas conversas un contexto cunha descrición e ábraas para que os usuarios conectados poidan atopalas e unirse a elas",
    "- See a read status and send failed messages again" : "- Vexa o estado de lectura e envíe de novo as mensaxes falladas",
    "- Raise your hand in a call with the R key" : "- Erga a man nunha chamada coa tecla R.",
    "- Join the same conversation and call from multiple devices" : "- Únase á mesma conversa e chame desde varios dispositivos",
    "- Send voice messages, share your location or contact details" : "- Envíe mensaxes de voz, comparta a súa localización ou os datos de contacto",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Engada grupos a unha conversa e engadiranse automaticamente novos membros ao grupo como participantes",
    "- A preview of your audio and video is shown before joining a call" : "- Amosase unha vista previa do seu son e vídeo antes de unirse a unha chamada",
    "- You can now blur your background in the newly designed call view" : "- Agora pode esvaer o seu fondo na vista de chamada de novo deseño",
    "- Moderators can now assign general and individual permissions to participants" : "- Os moderadores agora poden asignar permisos xerais e individuais aos participantes",
    "- You can now react to chat messages" : "- Agora pode reaccionar ás mensaxes de parola",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Agora pode atopar na barra lateral unha vista xeral dos últimos elementos compartidos",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Use unha enquisa para recoller as opinións dos demais ou definir unha cita",
    "- Configure an expiration time for chat messages" : "- Configure un tempo de caducidade para as mensaxes de parola",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Inicie chamadas sen notificar aos demais en grandes conversas. Pode enviar notificacións de chamadas individuais unha vez iniciada a chamada.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Envíe mensaxes de parola sen avisar aos destinatarios por se non é urxente",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Agora os «emojis» pódense completar automaticamente escribindo «:»",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Ligar varios elementos usando o novo selector intelixente escribindo unha «/»",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Agora os moderadores poden crear salas parciais (precisa dunha infraestrutura de alto rendemento)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Agora pódense gravar as chamadas (precisa dunha infraestrutura de alto rendemento)",
    "- Conversations can now have an avatar or emoji as icon" : "- Agora as conversas poden ter un avatar ou un «emoji» como icona",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Agora están dispoñíbeis fondos virtuais ademais do fondo esvaído nas videochamadas",
    "- Reactions are now available during calls" : "- Agora as reaccións están dispoñíbeis durante as chamadas",
    "- Typing indicators show which users are currently typing a message" : "- Os indicadores de escritura amosan cales son os usuarios que están a escribiren unha mensaxe",
    "- Groups can now be mentioned in chats" : "- Agora pódense mencionar grupos nas parolas",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- As gravacións de chamadas transcríbense automaticamente se se rexistra unha aplicación de provedor de transcrición",
    "- Chat messages can be translated if a translation provider app is registered" : "- As mensaxes da parola pódense traducir se se rexistra unha aplicación de provedor de tradución",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** agora pódese usar en mensaxes de _parola_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Xa están dispoñíbeis os puntos de ancoraxe web para implementar bots. Consulte a documentación para obter máis información en https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Definir un lembrete nunha mensaxe de parola para volver ser notificado máis tarde",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Use a conversa **Notas para un mesmo** para tomar notas e compartir información entre os teus dispositivos",
    "- Captions allow to send a message with a file at the same time" : "- As lendas permiten enviar unha mensaxe cun ficheiro ao mesmo tempo",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Agora é visíbel o vídeo do relator mentres se comparte a pantalla e as reaccións ás chamadas están animadas",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Agora os autores e moderadores que teñan accedido poden editar as mensaxes durante 6 horas",
    "- Unsent message drafts are now saved in your browser" : "- Os borradores de mensaxes sen enviar agora gárdanse no seu navegador",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- A parola de texto agora pódese facer de xeito federado con outros servidores de Parladoiro",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Agora os moderadores poden prohibir contas e convidados para evitar que se reincorporen a unha conversa",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- As próximas chamadas de eventos de calendario vinculados e as substitucións «fóra da oficina» agora amosanse nas conversas",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- As chamadas agora pódense facer de xeito federado con outros servidores de Parladoiro (precisa dunha infraestrutura de alto rendemento)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Presentación do cliente de escritorio Parladoiro de Nextcloud para Windows, macOS e Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Resume as gravacións de chamadas e as mensaxes non lidas nas parolas co Asistente de Nextcloud",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Xuntanzas melloradas co recoñecemento de convidados a través do seu enderezo de correo-e, importación de listas de participantes, borradores para enquisas e descarga de listas de participantes nas chamadas",
    "- Archive conversations to stay focused" : "- Arquivar as conversas para manter a focalización",
    "- Schedule a meeting into your calendar from within a conversation" : "- Programe unha xuntanza no seu calendario desde unha conversa",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Busque mensaxes da conversa actual directamente na barra lateral dereita",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Vexa máis conversas na primeira ollada coa nova lista compacta (activala nos axustes de Parladoiro)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- As conversas de xuntanza agora sincronizan o título e a descrición do calendario e están agochadas cun filtro de busca ata que estean preto do comezo",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Marcar as conversas como sensíbels na configuración de notificacións, para agochar o contido da mensaxe da lista de conversas e notificacións",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Para recibir notificacións emerxentes durante o modo «Non molestar» marque as conversas como importantes.",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Engadir outros participantes a unha chamada individualizada para crear unha nova chamada de grupo sobre a marcha",
    "- Use threads to keep your chat and discussions organized" : "- Use fíos para manter a parola e os debates organizados",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Agora están dispoñíbeis as transcricións en directo durante a chamada (precisa da ExApp de transcrición en directo e dunha infraestrutura de alto rendemento)",
    "- Moderators can now pin messages so they are kept at the top" : "- Agora os moderadores poden fixar mensaxes para mantelas na parte superior",
    "- Schedule a message to send it at a later time" : "- Programar unha mensaxe para enviala máis tarde",
    "_All %n participant_::_All %n participants_" : ["O único (%n) participante","Os %n participantes"],
    "Talk updates ✅" : "Actualizacións de Parladoiro ✅",
    "Reaction deleted by author" : "Reacción eliminada polo autor",
    "{actor} created the conversation" : "{actor} creou a conversa",
    "You created the conversation" : "Vde. creou a conversa",
    "System created the conversation" : "O sistema creou a conversa",
    "An administrator created the conversation" : "Alguén da administración do sitio creou a conversa",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} renomeou a conversa de «%1$s» a «%2$s»",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Vde. renomeou a conversa de «%1$s» a «%2$s»",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Alguén da administración do sitio renomeou a conversa de «%1$s» a «%2$s»",
    "{actor} set the description" : "{actor} definiu a descrición",
    "You set the description" : "Definiu a descrición",
    "An administrator set the description" : "Alguén da administración do sitio definiu a descrición",
    "{actor} removed the description" : "{actor} retirou a descrición",
    "You removed the description" : "Vde. retirou a descrición",
    "An administrator removed the description" : "Alguén da administración do sitio retirou a descrición",
    "You started a silent call" : "Vde. iniciou unha chamada silandeira",
    "Outgoing silent call" : "Chamada silandeira saínte",
    "{actor} started a silent call" : "{actor} iniciou unha chamada silandeira",
    "Incoming silent call" : "Chamada silandeira entrante",
    "You started a call" : "Vde. iniciou unha chamada",
    "Outgoing call" : "Chamada saínte",
    "{actor} started a call" : "{actor} iniciou unha chamada",
    "Incoming call" : "Chamada entrante",
    "{actor} joined the call" : "{actor} uniuse á chamada",
    "You joined the call" : "Vde. uniuse á chamada",
    "{actor} left the call" : "{actor} deixou a chamada",
    "You left the call" : "Vde. deixou a chamada",
    "{actor} unlocked the conversation" : "{actor} desbloqueou a conversa",
    "You unlocked the conversation" : "Vde. desbloqueou a conversa",
    "An administrator unlocked the conversation" : "Alguén da administración do sitio desbloqueou a conversa",
    "{actor} locked the conversation" : "{actor} bloqueou a conversa",
    "You locked the conversation" : "Vde. bloqueou a conversa",
    "An administrator locked the conversation" : "Alguén da administración do sitio bloqueou a conversa",
    "{actor} limited the conversation to the current participants" : "{actor} limitou a conversa aos participantes actuais",
    "You limited the conversation to the current participants" : "Vde. limitou a conversa aos participantes actuais",
    "An administrator limited the conversation to the current participants" : "Alguén da administración do sitio limitou a conversa aos participantes actuais",
    "{actor} opened the conversation to registered users" : "{actor} abriu a conversa aos usuarios rexistrados",
    "You opened the conversation to registered users" : "Vde. abriu a conversa aos usuarios rexistrados",
    "An administrator opened the conversation to registered users" : "Alguén da administración do sitio abriu a conversa aos usuarios rexistrados",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} abriu a conversa aos usuarios rexistrados e aos usuarios creados coa aplicación de Convidados (Guests)",
    "You opened the conversation to registered users and users created with the Guests app" : "Vde. abriu a conversa aos usuarios rexistrados e aos usuarios creados coa aplicación de Convidados (Guests)",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Alguén da administración do sitio abriu a conversa aos usuarios rexistrados e aos usuarios creados coa aplicación de Convidados (Guests)",
    "The conversation is now open to everyone" : "A conversa agora está aberta a todos",
    "{actor} opened the conversation to everyone" : "{actor} abriu a conversa a todos",
    "You opened the conversation to everyone" : "Vde. abriu a conversa a todos",
    "{actor} restricted the conversation to moderators" : "{actor} restrinxiu a conversa aos moderadores",
    "You restricted the conversation to moderators" : "Vde. restrinxiu a conversa aos moderadores",
    "{actor} started breakout rooms" : "{actor} iniciou salas parciais",
    "You started breakout rooms" : "Vde. iniciou salas parciais",
    "{actor} stopped breakout rooms" : "{actor} detivo as salas parciais",
    "You stopped breakout rooms" : "Vde. detivo as salas parciais",
    "{actor} allowed guests" : "{actor} permitiu convidados",
    "You allowed guests" : "Vde. permitiu convidados",
    "An administrator allowed guests" : "Alguén da administración do sitio permitiu convidados",
    "{actor} disallowed guests" : "{actor} retirou o permiso de convidados",
    "You disallowed guests" : "Vde. retirou o permiso de convidados",
    "An administrator disallowed guests" : "Alguén da administración do sitio retirou o permiso de convidados",
    "{actor} set a password" : "{actor} definiu un contrasinal",
    "You set a password" : "Vde. definiu un contrasinal",
    "An administrator set a password" : "Alguén da administración do sitio definiu un contrasinal",
    "{actor} removed the password" : "{actor} retirou o contrasinal",
    "You removed the password" : "Vde. retirou o contrasinal",
    "An administrator removed the password" : "Alguén da administración do sitio retirou o contrasinal",
    "{actor} added {user}" : "{actor} engadiu a {user}",
    "You joined the conversation" : "Vde. uniuse á conversa",
    "{actor} joined the conversation" : "{actor} uniuse á conversa",
    "You added {user}" : "Vde.  engadiu a {user}",
    "{actor} added you" : "{actor} engadiuno a Vde.",
    "An administrator added you" : "Alguén da administración do sitio engadiuno a Vde.",
    "An administrator added {user}" : "Alguén da administración do sitio engadiu a {user}",
    "You left the conversation" : "Vde. deixou a conversa",
    "{actor} left the conversation" : "{actor} deixou a conversa",
    "{actor} removed {user}" : "{actor} retirou a {user}",
    "You removed {user}" : "Vde. retirou a {user}",
    "{actor} removed you" : "{actor} retirouno. a Vde.",
    "An administrator removed you" : "Alguén da administración do sitio retirouno a Vde.",
    "An administrator removed {user}" : "Alguén da administración do sitio retirou a {user}",
    "{actor} invited {federated_user}" : "{actor} convidou a {federated_user}",
    "You invited {federated_user}" : "Vde. convidou a {federated_user}",
    "You accepted the invitation" : "Vde. aceptou o convite",
    "{actor} invited you" : "Vde. foi convidado por {actor}",
    "An administrator invited you" : "Vde. foi convidado por unha persoa de administración",
    "An administrator invited {federated_user}" : "Alguén da administración do sitio convidou a {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} aceptou o convite",
    "{actor} removed {federated_user}" : "{actor} retirou a {federated_user}",
    "You removed {federated_user}" : "Vde. retirou a {federated_user}",
    "You declined the invitation" : "Vde. declinou o convite",
    "An administrator removed {federated_user}" : "Alguén da administración do sitio retirou a {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} declinou o convite",
    "{actor} added group {group}" : "{actor} engadiu o grupo {group}",
    "You added group {group}" : "Vde. engadiu o grupo {group}",
    "An administrator added group {group}" : "Alguén da administración do sitio engadiu o grupo {group}",
    "{actor} removed group {group}" : "{actor} retirou o grupo {group}",
    "You removed group {group}" : "Vde. retirou o grupo {group}",
    "An administrator removed group {group}" : "Alguén da administración do sitio retirou o grupo {group}",
    "{actor} added team {circle}" : "{actor} engadiu o equipo {circle}",
    "You added team {circle}" : "Vde. engadiu o equipo {circle}",
    "An administrator added team {circle}" : "Alguén da administración do sitio engadiu o equipo {circle}",
    "{actor} removed team {circle}" : "{actor} retirou o equipo {circle}",
    "You removed team {circle}" : "Vde. retirou o equipo {circle}",
    "An administrator removed team {circle}" : "Alguén da administración do sitio retirou o equipo {circle}",
    "{actor} added {phone}" : "{actor} engadiu a {phone}",
    "You added {phone}" : "Vde. engadiu a {phone}",
    "An administrator added {phone}" : "Alguén da administración do sitio engadiu a {phone}",
    "{actor} removed {phone}" : "{actor} retirou a {phone}",
    "You removed {phone}" : "Vde. retirou a {phone}",
    "An administrator removed {phone}" : "Alguén da administración do sitio retirou a {phone}",
    "{actor} promoted {user} to moderator" : "{actor} promoveu a {user} a moderador",
    "You promoted {user} to moderator" : "Vde. promoveu a {user} a moderador",
    "{actor} promoted you to moderator" : "{actor} promoveuno a Vde. a moderador",
    "An administrator promoted you to moderator" : "Alguén da administración do sitio promoveuno a Vde. a moderador",
    "An administrator promoted {user} to moderator" : "Alguén da administración do sitio promoveuno a {user} a moderador",
    "{actor} demoted {user} from moderator" : "{actor} relegou a {user} de moderador",
    "You demoted {user} from moderator" : "Vde. relegou a {user} de moderador",
    "{actor} demoted you from moderator" : "{actor} relegouno a Vde. de moderador",
    "An administrator demoted you from moderator" : "Alguén da administración do sitio relegouno a Vde. de moderador",
    "An administrator demoted {user} from moderator" : "Alguén da administración do sitio relegou a {user} de moderador",
    "{actor} shared a file which is no longer available" : "{actor} compartiu un ficheiro que xa non está dispoñíbel",
    "You shared a file which is no longer available" : "Vde. compartiu un ficheiro que xa non está dispoñíbel",
    "File shares are currently not supported in federated conversations" : "A compartición de ficheiros non está admitida actualmente nas conversas federadas",
    "The shared location is malformed" : "A localización compartida ten un formato incorrecto",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} configurou Matterbridge para sincronizar esta conversa con outras salas de parolas",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Vde. configurou Matterbridge para sincronizar esta conversa con outras salas de parolas",
    "{actor} created thread {title}" : "{actor} creou o fío {title}",
    "You created thread {title}" : "Vde. creou o fío {title}",
    "{actor} renamed thread {title}" : "{actor} renomeou o fío {title}",
    "You renamed thread {title}" : "Vde. renomeou o fío {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} actualizou a configuración de Matterbridge",
    "You updated the Matterbridge configuration" : "Vde. actualizou a configuración do Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} retirou a configuración de Matterbridge",
    "You removed the Matterbridge configuration" : "Vde. retirou a configuración do Matterbridge",
    "{actor} started Matterbridge" : "{actor} iniciou Matterbridge",
    "You started Matterbridge" : "Vde. iniciou Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} detivo Matterbridge",
    "You stopped Matterbridge" : "Vde. detivo Matterbridge",
    "{actor} deleted a message" : "{actor} eliminou unha",
    "You deleted a message" : "Vde. eliminou unha mensaxe",
    "{actor} edited a message" : "{actor} editou unha mensaxe",
    "You edited a message" : "Vde. editou unha mensaxe",
    "{actor} pinned a message" : "{actor} fixou unha mensaxe",
    "You pinned a message" : "Vde. fixou unha mensaxe",
    "{actor} unpinned a message" : "{actor} desprendeu unha mensaxe",
    "Message was automatically unpinned" : "A mensaxe foi desprendida automaticamente",
    "You unpinned a message" : "Vde. desprendeu unha mensaxe",
    "{actor} deleted a reaction" : "{actor} eliminou unha reacción",
    "You deleted a reaction" : "Vde. eliminou unha reacción",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Definiu a caducidade da mensaxe en %n semana","Definiu a caducidade da mensaxe en %n semanas"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Definiu a caducidade da mensaxe en %n día","Definiu a caducidade da mensaxe en %n días"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Definiu a caducidade da mensaxe en %n hora","Definiu a caducidade da mensaxe en %n horas"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Definiu a caducidade da mensaxe en %n minuto","Definiu a caducidade da mensaxe en %n minutos"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} definiu a caducidade da mensaxe en %n semana","{actor} definiu a caducidade da mensaxe en %n semanas"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} definiu a caducidade da mensaxe en %n día","{actor} definiu a caducidade da mensaxe en %n días"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} definiu a caducidade da mensaxe en %n hora","{actor} definiu a caducidade da mensaxe en %n horas"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} definiu a caducidade da mensaxe en %n minuto","{actor} definiu a caducidade da mensaxe en %n minutos"],
    "{actor} disabled message expiration" : "{actor} desactivou a caducidade da mensaxe",
    "You disabled message expiration" : "Vde. desactivou a caducidade da mensaxe",
    "{actor} cleared the history of the conversation" : "{actor} limpou o historial da conversa",
    "You cleared the history of the conversation" : "Vde. limpou o historial da conversa",
    "{actor} set the conversation picture" : "{actor} definiu a imaxe da conversa",
    "You set the conversation picture" : "Vde. definiu a imaxe da conversa",
    "{actor} removed the conversation picture" : "{actor} retirou a imaxe da conversa",
    "You removed the conversation picture" : "Vde. retirou a imaxe da conversa",
    "{actor} ended the poll {poll}" : "{actor} rematou a enquisa {poll}",
    "You ended the poll {poll}" : "Vde. rematou a enquisa {poll}",
    "{actor} started the video recording" : "{actor} iniciou a gravación en vídeo",
    "You started the video recording" : "Vde. iniciou a gravación en vídeo",
    "{actor} stopped the video recording" : "{actor} detivo a gravación en vídeo",
    "You stopped the video recording" : "Vde. detivo a gravación en vídeo",
    "{actor} started the audio recording" : "{actor} iniciou a gravación do son",
    "You started the audio recording" : "Vde. comezou a gravación do son",
    "{actor} stopped the audio recording" : "{actor} parou a gravación do son",
    "You stopped the audio recording" : "Vde. parou a gravación do son",
    "The recording failed" : "Produciuse un fallo na gravación",
    "Someone voted on the poll {poll}" : "Alguén votou na enquisa {poll}",
    "Message deleted by author" : "Mensaxe eliminada polo autor",
    "Message deleted by {actor}" : "Mensaxe eliminada por {actor}",
    "Message deleted by you" : "Mensaxe eliminada por Vde.",
    "Deleted user" : "Usuario eliminado",
    "Unknown number" : "Número descoñecido",
    "Administration" : "Administración",
    "System" : "Sistema",
    "%s (guest)" : "%s (convidado)",
    "Missed call" : "Chamada perdida",
    "Unanswered call" : "Chamada sen resposta",
    "Call ended (Duration {duration})" : "Chamada rematada (Duración {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "A chamada rematou, por mor de ter acadado a duración máxima da chamada (duración {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} rematou a chamada (duración {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Rematou a chamada con %n convidado, por mor de ter acadado a duración máxima da chamada (duración {duration})","Rematou a chamada con %n convidados, por mor de ter acadado a duración máxima da chamada (duración {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Rematou a chamada con %n convidado (duración {duration})","Rematou a chamada con %n convidados (duración {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} rematou a chamada con %n convidado (duración {duration})","{actor} rematou a chamada con %n convidados (duración {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Rematou a chamada con {user1}, por mor de ter acadado a duración máxima da chamada (duración {duration})",
    "Call with {user1} ended (Duration {duration})" : "Rematou a chamada con {user1} (duración {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} rematou a chamada con {user1} (duración {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Rematou a chamada con {user1} e {user2}, por mor de ter acadado a duración máxima da chamada (duración {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Rematou a chamada con {user1} e {user2} (duración {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} rematou a chamada con {user1} e {user2} (duración {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Rematou a chamada con {user1}, {user2} e {user3}, por mor de ter acadado a duración máxima da chamada (duración {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Rematou a chamada con {user1}, {user2} e {user3} (duración {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} rematou a chamada con {user1}, {user2} e {user3} (duración {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Rematou a chamada con {user1}, {user2}, {user3} e {user4}, por mor de ter acadado a duración máxima da chamada (duración {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Rematou a chamada con {user1}, {user2}, {user3} e {user4} (duración {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} rematou a chamada con {user1}, {user2}, {user3} e {user4} (duración {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Rematou a chamada con {user1}, {user2}, {user3}, {user4} e {user5}, por mor de ter acadado a duración máxima da chamada (duración {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Rematou a chamada con {user1}, {user2}, {user3}, {user4} e {user5} (duración {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} rematou a chamada con {user1}, {user2}, {user3}, {user4} e {user5} (duración {duration})",
    "Message of {user} in {conversation}" : "Mensaxe de {user} en {conversation}",
    "Message of {user}" : "Mensaxe de {user}",
    "Message of a deleted user in {conversation}" : "Mensaxe dun usuario eliminado en {conversation}",
    "Talk conversations" : "Conversas no Parladoiro",
    "Talk to %s" : "Parladoiro con %s",
    "An error occurred. Please contact your administrator." : "Produciuse un erro. Póñase en contacto cua administración desta instancia.",
    "Storage quota exceeded" : "Superouse a cota de almacenamento",
    "File not found" : "Non se atopou o ficheiro",
    "File is not shared, or shared but not with the user" : "O ficheiro non está compartido, ou compartido, pero non co usuario",
    "No account available to delete." : "Non hai conta dispoñíbel para eliminar.",
    "Poll" : "Enquisa",
    "Password needs to be set" : "É necesario definir o contrasinal",
    "Uploading the file failed" : "Produciuse un fallo ao enviar o ficheiro",
    "No image file provided" : "Non se forneceu ningún ficheiro de imaxe",
    "File is too big" : "O ficheiro é grande de máis",
    "Invalid file provided" : "O ficheiro fornecido non é válido",
    "Invalid image" : "Imaxe incorrecta",
    "Unknown filetype" : "Tipo de ficheiro descoñecido",
    "Talk mentions" : "Mencións en Parladoiro",
    "More conversations" : "Máis conversas",
    "Say hi to your friends and colleagues!" : "Saúde aos seus amigos e compañeiros!",
    "No unread mentions" : "Non hai mencións sen ler",
    "Call in progress" : "Chamada en proceso",
    "You were mentioned" : "Vde. foi mencionado",
    "Write to conversation" : "Escribir á conversa",
    "Writes event information into a conversation of your choice" : "Escribe a información do evento nunha conversa da súa escolla",
    "Missing email field in header line" : "Falta o campo de correo-e na liña de cabeceira",
    "Following lines are invalid: %s" : "As seguintes liñas non son válidas: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s convidouno á conversa «%2$s».",
    "You were invited to conversation \"%s\"." : "Foi convidado á conversa «%s».",
    "Conversation invitation" : "Convite á conversa",
    "Scheduled time" : "Hora programada",
    "Description" : "Descrición",
    "You can also dial-in via phone with the following details" : "Tamén pode chamar por teléfono cos seguintes detalles",
    "Dial-in information" : "Información sobre a marcación",
    "Meeting ID" : "ID da xuntanza",
    "Your PIN" : "O seu PIN",
    "Click the button below to join the lobby now." : "Prema no botón de embaixo para unirse agora ao ástrago.",
    "Click the link below to join the lobby now." : "Prema na ligazón de embaixo para unirse agora ao ástrago.",
    "Join lobby for \"%s\"" : "Unirse ao ástrago de «%s»",
    "Click the button below to join the conversation now." : "Prema no botón de embaixo para unirse agora á conversa.",
    "Click the link below to join the conversation now." : "Prema na ligazón de embaixo para unirse agora á conversa.",
    "Join \"%s\"" : "Unirse a «%s»",
    "Meeting" : "Xuntanza",
    "Password request: %s" : "Solicitude de contrasinal: %s",
    "Private conversation" : "Conversa privada",
    "Deleted user (%s)" : "Usuario eliminado (%s)",
    "Failed to upload call recording" : "Produciuse un fallo ao enviar a gravación da chamada",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "O servidor de gravación non foi quen de enviar a gravación da chamada {call}. Póñase en contacto coa administración da instancia.",
    "Share to chat" : "Compartir na parola",
    "Dismiss notification" : "Rexeitar a notificación",
    "Call recording now available" : "Xa está dispoñíbel a gravación de chamadas",
    "The recording for the call in {call} was uploaded to {file}." : "A gravación da chamada en {call} foi enviada a {file}.",
    "Transcript now available" : "Xa está dispoñíbel a transcrición",
    "The transcript for the call in {call} was uploaded to {file}." : "A transcrición da chamada en {call} foi enviada a {file}.",
    "Failed to transcript call recording" : "Produciuse un fallo ao transcribir a gravación da chamada",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "O servidor non foi quen de transcribir a gravación en {file} para a chamada en {call}. Póñase en contacto coa administración.",
    "Call summary now available" : "Xa está dispoñíbel o resumo da chamada",
    "The summary for the call in {call} was uploaded to {file}." : "O resumo da chamada en {call} foi enviada a {file}.",
    "Failed to summarize call recording" : "Produciuse un fallo ao resumir a gravación da chamada",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "O servidor non foi quen de resumir a gravación en {file} para a chamada en {call}. Póñase en contacto coa administración.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} convidouno a unirse a {roomName} en {remoteServer}",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "{user1} invited you to a federated conversation" : "{user} convidouno a unha conversa federada",
    "Someone reacted" : "Alguén reaccionou",
    "New message" : "Nova mensaxe",
    "Reminder" : "Lembrete",
    "Someone mentioned you" : "Alguén mencionouno a Vde.",
    "Notification" : "Notificación",
    "Someone reacted in a private conversation" : "Alguén reaccionou nunha conversa privada",
    "You received a message in a private conversation" : "Recibíu unha mensaxe nunha conversa privada",
    "Reminder in a private conversation" : "Lembrete nunha conversa privada",
    "Someone mentioned you in a private conversation" : "Alguén mencionouno nunha conversa privada",
    "Notification in a private conversation" : "Notificación nunha conversa privada",
    "Reminder: You in {call}" : "Lembrete: Vde. está na chamada {call}",
    "Reminder: {user} in {call}" : "Lembrete: {user} está na chamada {call}",
    "Reminder: Deleted user in {call}" : "Lembrete: usuario eliminado da chamada {call}",
    "Reminder: {guest} (guest) in {call}" : "Lembrete {guest} (convidado) na chamada {call}",
    "Reminder: Guest in {call}" : "Lembrete: convidado na chamada {call}",
    "{user} reacted with {reaction}" : "{user} reaccionou con {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} reaccionou con {reaction} en {call}",
    "Deleted user reacted with {reaction} in {call}" : "O usuario eliminado reaccionou con {reaction} en {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (convidado) reaccionou con {reaction} en {call}",
    "Guest reacted with {reaction} in {call}" : "O convidado reaccionou con {reaction} en {call}",
    "{user} in {call}" : "{user} en {call}",
    "Deleted user in {call}" : "Usuario eliminado en {call}",
    "{guest} (guest) in {call}" : "{guest} (convidado) en {call}",
    "Guest in {call}" : "Convidado en {call}",
    "{user} sent you a private message" : "{user} envioulle unha mensaxe privada",
    "{user} sent a message in conversation {call}" : "{user} enviou unha mensaxe na conversa {call}",
    "A deleted user sent a message in conversation {call}" : "Un usuario eliminado enviou unha mensaxe na conversa {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (convidado) enviou unha mensaxe na conversa {call}",
    "A guest sent a message in conversation {call}" : "Un convidado enviou unha mensaxe na conversa {call}",
    "{user} replied to your private message" : "{user} respondeu á súa mensaxe privada",
    "{user} replied to your message in conversation {call}" : "{user} respondeu á súa mensaxe na conversa {call}",
    "A deleted user replied to your message in conversation {call}" : "Un usuario eliminado respondeu á súa mensaxe na conversa {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (convidado) respondeu á súa mensaxe na conversa {call}",
    "A guest replied to your message in conversation {call}" : "Un convidado respondeu á súa mensaxe na conversa {call}",
    "Reminder: You in private conversation {call}" : "Lembrete: Vde. está nunha conversa privada {call}",
    "Reminder: A deleted user in private conversation {call}" : "Lembrete: un usuario eliminado da conversa privada {call}",
    "Reminder: {user} in private conversation" : "Lembrete: {user} está nunha conversa privada {call}",
    "Reminder: You in conversation {call}" : "Lembrete: Vde. está na conversa {call}",
    "Reminder: {user} in conversation {call}" : "Lembrete: {user} está na conversa {call}",
    "Reminder: A deleted user in conversation {call}" : "Lembrete: un usuario eliminado da conversa {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Lembrete:  {guest} (convidado) está na conversa {call}",
    "Reminder: A guest in conversation {call}" : "Lembrete: un convidado na conversa {call}",
    "{user} reacted with {reaction} to your private message" : "{user} reaccionou con {reaction} á súa mensaxe privada",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} reaccionou con {reaction} á súa mensaxe na conversa {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Un usuario eliminado reaccionou con {reaction} á súa mensaxe na conversa {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (convidado) reaccionou con {reaction} á súa mensaxe na conversa {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Un convidado reaccionou con {reaction} á túa mensaxe na conversa {call}",
    "{user} mentioned you in a private conversation" : "{user} mencionouno nunha conversa privada",
    "{user} mentioned group {group} in conversation {call}" : "{user} mencionou o grupo {group} na conversa {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} mencionou o equipo {team} na conversa {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} mencionou a todos na conversa {call}",
    "{user} mentioned you in conversation {call}" : "{user} mencionouno na conversa {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Un usuario eliminado mencionou o grupo {group} na conversa {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Un usuario eliminado mencionou o equipo {team} na conversa {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Un usuario eliminado mencionou a todos na conversa {call}",
    "A deleted user mentioned you in conversation {call}" : "Un usuario eliminado mencionouno na conversa {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (convidado) mencionou ao grupo {group} na conversa {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (convidado) mencionou o equipo {team} na conversa {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (convidado) mencionou a todos na conversa {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (convidado) mencionouno na conversa {call}",
    "A guest mentioned group {group} in conversation {call}" : "Un convidado mencionou ao grupo {group} na conversa {call}",
    "A guest mentioned team {team} in conversation {call}" : "Un convidado mencionou o equipo {team} na conversa {call}",
    "A guest mentioned everyone in conversation {call}" : "Un convidado mencionou a todos na conversa {call}",
    "A guest mentioned you in conversation {call}" : "Un convidado mencionouno na conversa {call}",
    "View message" : "Ver a mensaxe",
    "Dismiss reminder" : "Rexeitar o lembrete",
    "View chat" : "Ver a parola",
    "{user} invited you to a group conversation: {call}" : "{user} convidouno a unha conversa de grupo: {call}",
    "Join call" : "Unirse á chamada",
    "Answer call" : "Responder á chamada",
    "{user} would like to talk with you" : "A {user} gustaríalle conversar con Vde.",
    "Call back" : "Devolver a chamada",
    "You missed a call from {user}" : "Perdeu unha chamada de {user}",
    "Accept call" : "Aceptar a chamada",
    "Incoming phone call from {call}" : "Chamada de teléfono entrante de {call}",
    "You missed a phone call from {call}" : "Perdeu unha chamada de teléfono de {call}",
    "A group call has started in {call}" : "Iniciouse unha chamada de grupo en {call}",
    "You missed a group call in {call}" : "Perdeu unha chamada de grupo en {call}",
    "{email} is requesting the password to access {file}" : "{email} está solicitando o contrasinal para acceder a {file}",
    "{email} tried to request the password to access {file}" : "{email} tentou solicitar o contrasinal para acceder a {file}",
    "Someone is requesting the password to access {file}" : "Alguén está solicitando o contrasinal para acceder a {file}",
    "Someone tried to request the password to access {file}" : "Alguén tentou solicitar o contrasinal para acceder a {file}",
    "Open settings" : "Abrir os axustes",
    "Hosted signaling server added" : "Engadiuse o servidor de sinalización aloxado",
    "The hosted signaling server is now configured and will be used." : "O servidor de sinalización aloxado agora está configurado e vai ser empregado.",
    "Hosted signaling server removed" : "Retirouse o servidor de sinalización aloxado",
    "The hosted signaling server was removed and will not be used anymore." : "Foi retirado o servidor de sinalización aloxado e xa non vai ser usado.",
    "Hosted signaling server changed" : "Cargouse servidor de sinalización aloxado",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "A conta do servidor de sinalización aloxado cambiou o estado de «{oldstatus}» a «{newstatus}»",
    "pending" : "pendente",
    "active" : "activa",
    "expired" : "caducada",
    "blocked" : "bloqueada",
    "error" : "erro",
    "The certificate of {host} expires in {days} days" : "O certificado de {host} caduca en {days} días",
    "The certificate of {host} expired" : "Caducou o certificado de {host}",
    "Contact via Talk" : "Contacte mediante Parladoiro",
    "Open Talk" : "Abrir Parladoiro",
    "Default" : "Predeterminado",
    "Presentation" : "Presentación",
    "Webinar" : "Seminario web",
    "Conversations" : "Conversas",
    "Messages in current conversation" : "Mensaxes na conversa actual",
    "{user}" : "{user}",
    "Messages" : "Mensaxes",
    "{user} in {conversation}" : "{user} en {conversation}",
    "Messages in other conversations" : "Mensaxes noutras conversas",
    "One-to-one rooms always need to show the other users avatar" : "As salas individuais sempre deben amosar o avatar dos outros usuarios",
    "Invalid emoji character" : "Carácter «emoji» non válido",
    "Invalid background color" : "Cor de fondo non válida",
    "Avatar image is not square" : "A imaxe do avatar non é cadrada",
    "Room {number}" : "Sala {number}",
    "Other" : "Outro",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Produciuse un fallo na solicitude de proba porque o servidor de proba non é accesíbel. Ténteo de novo máis tarde.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Hai un problema coa autenticación desta instancia. Quizais non sexa accesíbel desde o exterior para verificar o seu URL.",
    "Something unexpected happened." : "Ocorreu algo non agardado.",
    "The URL is invalid." : "O URL non é valido",
    "An HTTPS URL is required." : "Precísase dun URL HTTPS",
    "The email address is invalid." : "O enderezo de correo-e non é válido",
    "The language is invalid." : "O idioma non é valido",
    "The country is invalid." : "O país non é valido",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Hai un problema coa petición de proba. Verifique os seus rexistros para obter máis información.",
    "Too many requests are send from your servers address. Please try again later." : "Envíanse demasiadas solicitudes desde o enderezo do servidor. Ténteo de novo máis tarde.",
    "There is already a trial registered for this Nextcloud instance." : "Xa hai unha proba rexistrada para esta instancia de Nextcloud.",
    "Something unexpected happened. Please try again later." : "Ocorreu algo non previsto. Ténteo de novo máis tarde.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Produciuse un fallo na solicitude de proba porque o servidor de proba comportouse erroneamente. Ténteo de novo máis tarde.",
    "Trial requested but failed to get account information. Please check back later." : "Proba solicitada pero non conseguiu a información da conta. Ténteo de novo máis tarde.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Hai un problema coa autenticación desta solicitude. Quizais non sexa accesíbel desde o exterior para verificar o seu URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Produciuse un fallo ao recuperar información da conta porque o servidor de proba comportouse erroneamente. Ténteo de novo máis tarde.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Hai un problema ao recuperar a información da conta. Verifique os seus rexistros para recuperar máis información.",
    "There is no such account registered." : "Non hai rexistrada unha conta deste tipo.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Produciuse un fallo ao recuperar información da conta porque non é posibel acadar o servidor de proba. Ténteo de novo máis tarde.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Produciuse un fallo ao eliminar a conta do servidor de sinalización aloxado. Ténteo de novo máis tarde.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Produciuse un fallo ao eliminar a conta porque o servidor de proba comportouse erroneamente. Ténteo de novo máis tarde.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Hai un problema ao eliminar a conta. Verifique os seus rexistros para obter máis información.",
    "Too many requests are sent from your servers address. Please try again later." : "Envíanse demasiadas solicitudes desde o enderezo do servidor. Ténteo de novo máis tarde.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Produciuse un fallo ao eliminar a conta porque non é posíbel acadar o servidor de proba. Ténteo de novo máis tarde.",
    "Note to self" : "Notas para un mesmo",
    "A place for your private notes, thoughts and ideas" : "Un lugar para as súas notas, pensamentos e ideas privadas",
    "Transcript is AI generated and may contain mistakes" : "A transcrición é xerada por IA e pode conter erros",
    "Summary is AI generated and may contain mistakes" : "O resumo é xerado por IA e pode conter erros",
    "Let's get started!" : "Comecemos!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Parladoiro de Nextcloud** é unha plataforma de comunicación segura en aloxamento autónomo que se integra perfectamente co ecosistema NextCloud.\n\n#### Funcionalidades principais de Parladoiro de NextCloud:\n\n* Parola e mensaxería en parolas privadas e en grupo\n* Chamadas de vox e vídeo\n* Compartir ficheiros e integración con outras aplicacións NextCloud\n* Axustes personalizábeis de conversa, moderación e controis de privacidade\n* Web, escritorio e móbil (iOS e Android)\n* Comunicación privada e segura\n\nObteña máis información na [Documentación do usuario](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Dámoslle a benvida a Parladoiro de Nextcloud\n\nParladoiro de Nextcloud é unha aplicación de mensaxería privada e potente que se integra con NextCloud. Parole en conversas privadas ou en grupo, participe en chamadas de voz e vídeo, organice seminarios e eventos, personalice as súas conversas e moito máis.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formatar textos para crear mensaxes melloradas\n\nEn Parladoiro de Nextcloud, pode usar a sintaxe Markdown para formatar as súas mensaxes. Por exemplo, aplique o formatado como **grosa** ou *cursiva*, ou `destaque textos como código`. Pode incluso crear táboas e engadir títulos ao seu texto.\n\nNecesita arranxar un erro de escritura ou cambiar o formatado? Edite a mensaxe premendo en «Editar mensaxe» no menú da mensaxe.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Engada anexos e ligazóns\n\nEngada ficheiros do seu NextCloud Hub empregando o botón «+». Comparta elementos de ficheiros e varias aplicacións de NextCloud. Algunhas aplicacións incluso admiten trebellos interactivos, por exemplo, a aplicación de Texto.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Deixe que as conversas flúan: mencione aos usuarios, reaccione ás mensaxes e máis…\n\nPode mencionar a todos nunha conversa empregando %s ou mencionar participantes específicos escribindo «@» e seleccionando o seu nome da lista.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Pode responder mensaxes, reenvialas a outras parolas e persoas ou copiar o contido da mensaxe.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Faga máis cousas co Selector intelixente\n\nSó ten que escribir «/» ou ir ao menú «+» para abrir o selector intelixente onde pode achegar diversos contidos ás súas mensaxes. Pode configurar o selector intelixente para poder engadir elementos de aplicacións de NextCloud, GIF, localizacións de mapas, contido xerado por IA e moito máis.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Xestionar os axustes da conversa\n\nNo menú de conversas, pode acceder a varios  axustes para xestionar as súas conversas, como:\n* Editar a información da conversa\n* Xestionar as notificacións\n* Aplicar numerosas regras de moderación\n* Configurar o acceso e a seguranza\n* Activar bots\n* E moito máis!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratos Árabes Unidos",
    "Afghanistan" : "Afganistán",
    "Antigua and Barbuda" : "Antiga e Barbuda",
    "Anguilla" : "Anguila",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antártida",
    "Argentina" : "Arxentina",
    "American Samoa" : "Samoa americana",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Illas de Åland",
    "Azerbaijan" : "Acerbaixán",
    "Bosnia and Herzegovina" : "Bosnia e Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélxica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Barein",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Saint Barthélemy" : "San Bartolomeu",
    "Bermuda" : "Bermudas",
    "Brunei Darussalam" : "Sultanato de Brunei",
    "Bolivia, Plurinational State of" : "Bolivia, Estado plurinacional de",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, San Eustaquio e Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bután",
    "Bouvet Island" : "Illa Bouvet",
    "Botswana" : "Botsuana",
    "Belarus" : "Belarús",
    "Belize" : "Belice",
    "Canada" : "Canadá",
    "Cocos (Keeling) Islands" : "Illas Cocos (Keeling)",
    "Congo, the Democratic Republic of the" : "Congo, República democrática do",
    "Central African Republic" : "República Centro Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suíza",
    "Côte d'Ivoire" : "Costa do Marfin",
    "Cook Islands" : "Illas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camerún",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Illa Nadal",
    "Cyprus" : "Chipre",
    "Czechia" : "República Checa",
    "Germany" : "Alemaña",
    "Djibouti" : "Xibutí",
    "Denmark" : "Dinamarca",
    "Dominica" : "Dominica",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Alxeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Exipto",
    "Western Sahara" : "Sáhara Ocidental",
    "Eritrea" : "Eritrea",
    "Spain" : "España",
    "Ethiopia" : "Etiopía",
    "Finland" : "Finlandia",
    "Fiji" : "Fidxi",
    "Falkland Islands (Malvinas)" : "Illas Malvinas (Falkland)",
    "Micronesia, Federated States of" : "Micronesia, Estados Federados da",
    "Faroe Islands" : "Illas Feroe",
    "France" : "Francia",
    "Gabon" : "Gabón",
    "United Kingdom of Great Britain and Northern Ireland" : "Reino Unido da Gran Bretaña e Irlanda do Norte",
    "Grenada" : "Granada",
    "Georgia" : "Xeorxia",
    "French Guiana" : "Guaiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Xibraltar",
    "Greenland" : "Grenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guinea Ecuatorial",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Illas Xeorxia do Sur e Sandwich do Sur",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bisau",
    "Guyana" : "Guiana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Illa Heard e Illas McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croacia",
    "Haiti" : "Haití",
    "Hungary" : "Hungría",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Illa de Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territorio Británico do Océano Índico",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Irán, República Islámica do",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jersey" : "Xersei",
    "Jamaica" : "Xamaica",
    "Jordan" : "Xordania",
    "Japan" : "Xapón",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Quirguistán",
    "Cambodia" : "Camboxa",
    "Kiribati" : "Kiribatí",
    "Comoros" : "Comores",
    "Saint Kitts and Nevis" : "San Cristovo e Nevis",
    "Korea, Democratic People's Republic of" : "Corea, República democrática popular de",
    "Korea, Republic of" : "Corea, República de",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Illas Caimán",
    "Kazakhstan" : "Cazaquistán",
    "Lao People's Democratic Republic" : "República Popular Democrática de Laos",
    "Lebanon" : "Líbano",
    "Saint Lucia" : "Santa Lucía",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Marrocos",
    "Monaco" : "Mónaco",
    "Moldova, Republic of" : "Moldavia, República da",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "San Martín (parte francesa)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Illas Marshall",
    "North Macedonia" : "Macedonia do Norte",
    "Mali" : "Malí",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Illas Marianas do Norte",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauricio",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nova Caledonia",
    "Niger" : "Níxer",
    "Norfolk Island" : "Illa Norfolk",
    "Nigeria" : "Nixeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Países Baixos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nova Celandia",
    "Oman" : "Omán",
    "Panama" : "Panamá",
    "Peru" : "Perú",
    "French Polynesia" : "Polinesia Francesa",
    "Papua New Guinea" : "Papúa Nova Guinea",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistán",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "San Pedro e Miquelón",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine, State of" : "Palestina, Estado de",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Réunion" : "Reunión",
    "Romania" : "Romanía",
    "Serbia" : "Serbia",
    "Russian Federation" : "Federación Rusa",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Illas Salomón",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudán",
    "Sweden" : "Suecia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Helena, Ascension e Tristán da Cuña",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Illas Svalbard e Jan Mayen",
    "Slovakia" : "Eslovaquia",
    "Sierra Leone" : "Serra Leoa",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudán do Sur",
    "Sao Tome and Principe" : "San Tomé e Príncipe",
    "El Salvador" : "O Salvador",
    "Sint Maarten (Dutch part)" : "San Martín (parte neerlandesa)",
    "Syrian Arab Republic" : "República Árabe de Siria",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Illas Turcas e Caicos",
    "Chad" : "Chad",
    "French Southern Territories" : "Territorios Franceses do Sur",
    "Togo" : "Togo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Taxiquistán",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor do Leste",
    "Turkmenistan" : "Turquemenistán",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquía",
    "Trinidad and Tobago" : "Trinidade e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan, Provincia de China",
    "Tanzania, United Republic of" : "Tanzania, República Unida de",
    "Ukraine" : "Ucraína",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Illas exteriores menores dos Estados Unidos",
    "United States of America" : "Estados Unidos de America",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbekuistán",
    "Holy See" : "Santa Sé (Vaticano)",
    "Saint Vincent and the Grenadines" : "San Vicente e as Granadinas",
    "Venezuela, Bolivarian Republic of" : "Venezuela, República Bolivariana de",
    "Virgin Islands, British" : "Illas Virxes, Británicas",
    "Virgin Islands, U.S." : "Illas Virxes, EE.UU.",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Illas Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iemen",
    "Mayotte" : "Maiote",
    "South Africa" : "Suráfrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Cimbabue",
    "Background blur" : "Esvaer o fondo",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Non foi posíbel comprobar a compatibilidade de carga de WASM. Comprobe manualmente se o seu servidor web serve ficheiros «.wasm».",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "O seu servidor web non está configurado correctamente para entregar ficheiros «.wasm». Este é normalmente un problema coa configuración de Nginx. Para o esvaemento do fondo, necesita un axuste para entregar tamén ficheiros «.wasm». Compare a súa configuración de Nginx coa configuración recomendada na nosa documentación.",
    "Talk configuration values" : "Valores de configuración de Parladoiro",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Forzar a duración dunha chamada só é posíbel co cron do sistema. Active o cron do sistema ou retirar a configuración «max_call_duration».",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Os valores pequenos de «max_call_duration» (actualmente definidos en %d) non son aplicábeis por mor de limitacións técnicas. O traballo en segundo plano só se executa cada 5 minutos, úseo baixo a súa responsabilidade.",
    "Federation" : "Federación",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Recoméndase encarecidamente configurar «memcache.locking» cando estea activada a federación de Parladoiro.",
    "High-performance backend" : "Infraestrutura de alto rendemento",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "A infraestrutura de alto rendemento está sen configurar: a execución de Parladoiro de Nextcloud sen a infraestrutura de alto rendemento só se adapta a chamadas moi pequenas (máx. 2-3 participantes). Configure a infraestrutura de alto rendemento para garantir que as chamadas con varios participantes funcionen sen problemas.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Executar a infraestrutura de alto rendemento en modo «conversation_cluster» está obsoleto e non vai estar admitido na próxima versión. Hoxe en día, a infraestrutura de alto rendemento admite a agrupación en clústeres reais, que é o que debería ser empregado.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "A definición de varias infraestruturas de alto rendemento está en desuso e xa non se admitirá na próxima versión. En troques, débese configurar un balanceador de carga xunto cos servidores de sinalización en clúster e configurarse nos axustes de Parladoiro.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "A chave pública almacenada para o algoritmo usado %1$s non coincide coa chave privada almacenada. Execute %2$s para arranxar o problema.",
    "High-performance backend not configured correctly. Run %s for details." : "A infraestrutura de alto rendemento non está configurada correctamente. Execute %s para obter detalles-",
    "High-performance backend not configured correctly" : "A infraestrutura de alto rendemento non está configurada correctamente",
    "Error: Cannot connect to server" : "Erro: Non foi posíbel conectar co servidor",
    "Error: Server did not respond with proper JSON" : "Erro: o servidor non respondeu con JSON axeitado",
    "Error: Certificate expired" : "Erro: caducou o certificado",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Erro: a hora do sistema do servidor Nextcloud e do servidor da infraestrutura de alto rendemento non están sincronizadas. Asegúrese de que ambos os servidores estean conectados a un servidor de hora ou sincronice manualmente a súa hora.",
    "Could not get version" : "Non foi posíbel obter a versión",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Erro: Versión en execución: {version}; Debe actualizar o servidor para que sexa compatíbel con esta versión de Parladoiro",
    "Error: Server responded with: {error}" : "Erro: o servidor respondeu con: {error}",
    "Error: Unknown error occurred" : "Erro: produciuse un erro descoñecido",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Advertencia: Versión en execución: {versión}; O servidor non admite todas as funcionalidades desta versión de Talk, faltan as funcionalidades: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "É moi recomendábel configurar unha memoria tobo cando se executa Parladoiro de Nextcloud cunha infraestrutura de alto rendemento.",
    "Client Push" : "Notificación automática ao cliente",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "A notificación automática ao cliente está instalada, isto mellora a puntualidade das notificacións de Parladoiro.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} non está instalada. Isto pode provocar un atraso nas notificacións de Parladoiro.",
    "Recording backend" : "Infraestrutura de gravación",
    "Using the recording backend requires a High-performance backend." : "O uso da infraestrutura de gravación precisa dunha infraestrutura de alto rendemento.",
    "No recording backend configured" : "Non hai ningunha infraestrutura de gravación configurada",
    "SIP configuration" : "Configuración SIP",
    "Using the SIP functionality requires a High-performance backend." : "O uso da funcionalidade SIP precisa dunha infraestrutura de alto rendemento.",
    "No SIP backend configured" : "Non hai ningunha infraestrutura SIP configurada",
    "Invalid date, date format must be YYYY-MM-DD" : "Data incorrecta, o formato da data debe ser AAAA-MM-DD",
    "Conversation not found" : "Non se atopou a conversa",
    "Path is already shared with this conversation" : "A ruta xa está compartida con esta conversa",
    "Chat, video & audio-conferencing using WebRTC" : "Parolas, conferencias de vídeo e son empregando WebRTC ",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Parolas, conferencias de vídeo e son empregando WebRTC \n\n* 💬 **Parolar** Parladoiro de Nextcloud inclúe parolas de texto simple, que lle permite compartir ou enviar ficheiros desde a súa aplicación Nextcloud Ficeiros ou dispositivo local e mencionar a outros participantes.\n* 👥 **Chamadas privadas, grupais, públicas e protexidas por contrasinal!** Convide a alguén, a todo un grupo ou envíe unha ligazón pública para convidar a unha chamada.\n* 🌐 **Parolas federadas** Parole con outros usuarios de Nextcloud nos seus servidores\n* 💻 **Compartir pantalla!** Comparta a súa pantalla cos participantes na súa chamada.\n* 🚀 **Integración con outras aplicacións de Nextcloud** como Ficheiros, Calendario, Estado do usuario, Taboleiro, Fluxo, Mapas, Selector intelixente, Contactos, Gabeta e moitos máis.\n* 🌉 **Sincronizar con outras solucións de parola** Con [Matterbridge]https://github.com/42wim/matterbridge/) integrado en Parladoiro, pode sincronizar de xeito doado moitas outras solucións de parolas con Parladoiro de Nextcloud e viceversa.",
    "Leave call" : "Abandonar a chamada",
    "Navigating away from the page will leave the call in {conversation}" : "A navegación fora da páxina provocará o abandono da chamada en {conversation}",
    "Stay in call" : "Mantérse na chamada",
    "Error occurred when getting the conversation information" : "Produciuse un erro ao obter a información da conversa",
    "Discuss this file" : "Debater sobre este ficheiro",
    "Share this file with others to discuss it" : "Comparta este ficheiro cos demais para debater sobre el",
    "Share this file" : "Compartir este ficheiro",
    "Join conversation" : "Unirse á conversa",
    "This conversation is password-protected." : "Esta conversa está protexida con contrasinal.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Detectamos varios intentos de contrasinal non válidos desde o seu IP. Por mor diso, o seu próximo intento estará limitado a 30 segundos.",
    "The password is wrong. Try again." : "O contrasinal é incorrecto. Ténteo de novo.",
    "Password" : "Contrasinal",
    "Submit" : "Enviar",
    "Error requesting the password." : "Produciuse un erro ao solicitar o contrasinal.",
    "Request password" : "Solicitar contrasinal",
    "This conversation has ended" : "Esta conversa rematou",
    "Error occurred when joining the conversation" : "Produciuse un erro ao unirse á conversa",
    "Close Talk sidebar" : "Pechar a barra lateral de Parladoiro",
    "Open Talk sidebar" : "Abrir a barra lateral de Parladoiro",
    "Everyone" : "Todos",
    "Users and moderators" : "Usuarios e moderadores",
    "Moderators only" : "Só os moderadores",
    "Disable calls" : "Desactivar chamadas",
    "Save changes" : "Gardar cambios",
    "Saving …" : "Gardando…",
    "Saved!" : "Gardado!",
    "Limit to groups" : "Límite para grupos",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Cando se selecciona polo menos un grupo, só as persoas dos grupos listados poden formar parte das conversas.",
    "Guests can still join public conversations." : "Os convidados aínda poden unirse a conversas públicas.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Os usuarios que xa non poidan usar Parladoiro seguirán figurando como participantes nas súas conversas anteriores e tamén se conservarán as súas mensaxes de parolas.",
    "Limit using Talk" : "Limitar o uso de Parladoiro",
    "Limit creating a public and group conversation" : "Limitar a creación dunha conversa pública e de grupo",
    "Limit creating conversations" : "Limitar a creación de conversas",
    "Limit starting a call" : "Limitar o inicio dunha chamada",
    "Limit starting calls" : "Limitar o inicio de chamadas",
    "When a call has started, everyone with access to the conversation can join the call." : "Cando inicia unha chamada, todos os que teñen acceso á conversa poden unirse á chamada.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Neste servidor están instalados os seguintes bots. Na documentación pode atopar detalles sobre como {linkstart1}construír o seu propio bot{linkend} ou unha {linkstart2}lista de bots{linkend} para activar no seu servidor.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Non hai ningún bot instalado neste servidor. Na documentación pode atopar detalles sobre como {linkstart1}construír o seu propio bot{linkend} ou unha {linkstart2}lista de bots{linkend} para activar no seu servidor.",
    "Description is not provided" : "Non se fornece a descrición",
    "Locked for moderators" : "Bloqueado para moderadores",
    "Enabled" : "Activado",
    "Disabled" : "Desactivado",
    "Bots settings" : "Axustes dos bots",
    "State" : "Estado",
    "Name" : "Nome",
    "Last error" : "Último erro",
    "Total errors count" : "Reconto total de erros",
    "Find more bots" : "Atopar máis bots",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Os servidores de confianza pódense configurar na {linkstart}Páxina de axustes da compartición{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "As parolas e as chamadas federadas xa funcionan. O manexo de anexos chegará nunha versión futura.",
    "Enable Federation in Talk app" : "Activar a federación na aplicación Parladoiro",
    "Permissions" : "Permisos",
    "Allow users to be invited to federated conversations" : "Permitir que os usuarios sexan convidados a conversas federadas",
    "Allow users to invite federated users into conversation" : "Permitir que os usuarios conviden a usuarios federados á conversa",
    "Only allow to federate with trusted servers" : "Permitir federarse só con servidores de confianza",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Cando se selecciona polo menos un grupo, só as persoas dos grupos listados poden convidar usuarios federados a conversas.",
    "Groups allowed to invite federated users" : "Grupos autorizados para convidar usuarios federados",
    "Select groups …" : "Seleccionar grupos…",
    "All messages" : "Todas as mensaxes",
    "@-mentions only" : "Só as mencións con @",
    "Off" : "Apagado",
    "General settings" : "Axustes xerais",
    "Default notification settings" : "Axustes predeterminados das notificacións",
    "Default group notification" : "Notificación predeterminada de grupo",
    "Default group notification for new groups" : "Notificación predeterminada de grupo para novos grupos",
    "Integration into other apps" : "Integración noutras aplicacións",
    "Allow conversations on files" : "Permitir conversas en ficheiros",
    "Allow conversations on public shares for files" : "Permitir conversas en comparticións públicas de ficheiros",
    "End-to-end encrypted calls" : "Chamadas cifradas de extremo a extremo",
    "Enable encryption" : "Activar a cifraxe",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "As chamadas cifradas de extremo a extremo cunha ponte SIP configurada precisan dunha versión máis recente da infraestrutura de alto rendemento e da ponte SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Os clientes móbiles non admiten chamadas cifradas de extremo a extremo polo momento.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Premendo no botón superior á información do formulario envíase aos servidores de Struktur AG. Pode atopar máis información en {linkstart}spreed.eu{linkend}.",
    "Pending" : "Pendentes",
    "Error" : "Erro",
    "Blocked" : "Bloqueado",
    "Active" : "Activo",
    "Expired" : "Caducado",
    "Never" : "Nunca",
    "The trial could not be requested. Please try again later." : "Non foi posíbel solicitar a proba. Ténteo de novo máis tarde.",
    "The account could not be deleted. Please try again later." : "Non foi posíbel eliminar a conta. Ténteo de novo máis tarde.",
    "Hosted High-performance backend" : "Infraestrutura de alto rendemento aloxada",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "O noso socio Struktur AG ofrece un servizo onde se pode solicitar un servidor de sinalización aloxado. Para isto, só ten que cumprimentar o seguinte formulario e o seu Nextcloud solicitarao. Unha vez que o servidor estea configurado  para Vde., as credenciais encheranse automaticamente. Isto sobrescribirá os axustes do servidor de sinalización existente.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Se a súa conta de infraestrutura de alto rendemento inclúe a funcionalidade STUN e/ou TURN, actualizaranse os axustes en consecuencia.",
    "URL of this Nextcloud instance" : "URL desta instancia de Nextcloud",
    "Full name of the user requesting the trial" : "Nome completo do usuario que solicita a proba",
    "Email of the user" : "Correo-e do usuario",
    "Language" : "Idioma",
    "Country" : "País",
    "Request signaling server trial" : "Solicitar a proba do servidor de sinalización",
    "You can see the current status of your hosted signaling server in the following table." : "Pode ver o estado actual do servidor de sinalización aloxado na seguinte táboa.",
    "Status" : "Estado",
    "Created at" : "Creado ás",
    "Expires at" : "Caduca ás",
    "Limits" : "Limites",
    "STUN included" : "STUN incluído",
    "Yes" : "Si",
    "No" : "Non",
    "TURN included" : "TURN incluído",
    "Delete the signaling server account" : "Eliminar a conta do servidor de sinalización",
    "_%n user_::_%n users_" : ["%n usuario","%n usuarios"],
    "Installed version: {version}" : "Versión instalada: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Pode instalar Matterbridge para vincular Parladoiro de Nextcloud con outros servizos, visite a súa {linkstart1}páxina de GitHub{linkend} para obter máis detalles. A descarga e a instalación da aplicación pode levar un tempo. No caso de que se esgote, instáleo manualmente desde a {linkstart2}tenda de aplicacións de Nextcloud{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "O binario do Matterbridge ten permisos incorrectos. Asegúrese de que o ficheiro binario do Matterbridge é propiedade do usuario correcto e que se pode executar. Pódeo atopar en «/…/nextcloud/apps/talk_matterbridge/bin/».",
    "Matterbridge binary was not found or couldn't be executed." : "Non se atopou o binario do Matterbridge  ou non foi posíbel executalo.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Tamén pode configurar a ruta ao binario d Matterbridge manualmente a través da configuración. Consulte a {linkstart}documentación de integración con Matterbridge{linkend} para obter máis información.",
    "Downloading …" : "Descargando…",
    "Install Talk Matterbridge" : "Instalar «Talk Matterbridge»",
    "An error occurred while installing the Matterbridge app" : "Produciuse un erro ao instalar a aplicación Matterbridge.",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Produciuse un erro ao instalar «Talk Matterbridge». Instáleo manualmente",
    "Failed to execute Matterbridge binary." : "Produciuse un fallo ao executar o binario de Matterbridge.",
    "Matterbridge integration" : "Integración de Matterbridge",
    "Enable Matterbridge integration" : "Activar a integración de Matterbridge",
    "Status: Checking connection" : "Estado: comprobando a conexión",
    "OK: Running version: {version}" : "Correcto: executando a versión: {version}",
    "Error: Server seems to be a Signaling server" : "Erro: o servidor parece ser un servidor de sinalización",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Erro: os tempos do sistema do servidor Nextcloud e do servidor da infraestrutura de gravación non están sincronizados. Asegúrese de que ambos os servidores estean conectados a un servidor de tempo ou sincronice manualmente a súa hora.",
    "Recording backend URL" : "URL da infraestrutura de gravación",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Delete this server" : "Eliminar este servidor",
    "Test this server" : "Probar este servidor",
    "Disabled for all calls" : "Desactivado para todas as chamadas",
    "Enabled for all calls" : "Activado para todas as chamadas",
    "Configurable on conversation level by moderators" : "Configurábel a nivel de conversa polos moderadores",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "O axuste de PHP «upload_max_filesize» ou «post_max_size» só permitirá enviar ficheiros ata {maxUpload}.",
    "Recording backend settings saved" : "Gardáronse os axustes da infraestrutura de gravación",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Os moderadores poderán activar o consentimento a nivel de conversa. O consentimento para gravar será necesario para cada participante antes de unirse a cada chamada desta conversa.",
    "The consent to be recorded will be required for each participant before joining every call." : "O consentimento para ser gravado será necesario para cada participante antes de unirse a cada chamada.",
    "The consent to be recorded is not required." : "Non é necesario o consentimento para ser gravado.",
    "Recording backend configuration is only possible with a High-performance backend." : "A configuración da infraestrutura de gravación só é posíbel cunha infraestrutura de alto rendemento.",
    "Add a new recording backend server" : "Engadir un novo servidor de infraestrutura de gravación",
    "Shared secret" : "Segredo compartido",
    "Recording consent" : "Consentimento de gravación",
    "Recording transcription" : "Transcrición da gravación",
    "Automatically transcribe call recordings with a transcription provider" : "Transcribe automaticamente as gravacións de chamadas cun provedor de transcrición",
    "Automatically summarize call recordings with transcription and summary providers" : "Resume automaticamente as gravacións de chamadas con provedores de transcrición e resumo",
    "SIP configuration saved!" : "Configuración SIP gardada!",
    "SIP configuration is only possible with a High-performance backend." : "A configuración SIP só é posíbel cunha infraestrutura de alto rendemento.",
    "Enable SIP Dial-out option" : "Activar a opción de marcación SIP",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "O servidor de sinalización ten que ser actualizado para a funcionalidade de marcación SIP compatíbel.",
    "Do not show SIP Dial-out caller number" : "Non amosar o número de chamada saínte de SIP",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "O número anónimo debe aparecer como «descoñecido» ou «número agochado» para o destinatario da chamada",
    "Dial-out number" : "Número de chamada saínte",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Número con formato E164 usado como número de chamada alternativo para chamadas saíntes",
    "Dial-out prefix" : "Prefixo de marcado",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Prefixo ao número de usuario configurado para as chamadas saíntes (o predeterminado é «+»)",
    "Restrict SIP configuration" : "Restrinxir a configuración SIP",
    "Enable SIP configuration" : "Activar a configuración SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Só os usuarios dos seguintes grupos poden activar SIP nas conversas que moderan",
    "Phone number (Country)" : "Número de teléfono (País)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Esta información envíase en correos-e de convite e amosase na barra lateral a todos os participantes.",
    "Nextcloud base URL" : "URL base de Nextcloud",
    "Talk Backend URL" : "URL da infraestrutura de Parladoiro",
    "WebSocket URL" : "URL de WebSocket",
    "Available features" : "Funcionalidades dispoñíbeis",
    "Error: Websocket connection failed" : "Erro: produciuse un fallo na conexión de Websocket.",
    "Error code" : "Código de erro",
    "Error message" : "Mensaxe de erro",
    "Error: Websocket connection failed. Check browser console" : "Erro: produciuse un fallo na conexión de Websocket. Comprobe a consola do navegador",
    "High-performance backend URL" : "URL da infraestrutura de alto rendemento",
    "Missing High-performance backend warning hidden" : "Falta a advertencia de infraestrutura de alto rendemento agochada",
    "High-performance backend settings saved" : "Gardáronse os axustes da infraestrutura de alto rendemento",
    "Nextcloud Talk setup not complete" : "A configuración de Parladoiro de Nextcloud non está completa",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Teña en conta que nas chamadas con máis de 2 participantes sen a infraestrutura de alto rendemento, é probábel que os participantes experimenten problemas de conectividade e provoquen unha gran carga nos dispositivos participantes.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Instale a infraestrutura de alto rendemento para garantir que as chamadas con varios participantes funcionen sen problemas.",
    "Nextcloud portal" : "Portal de Nextcloud",
    "Quick installation guide" : "Guía de instalación rápida",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "A infraestrutura de alto rendemento é necesaria para chamadas e conversas con varios participantes. Sen a infraestrutura, todos os participantes teñen que enviar o seu propio vídeo individualmente para cada outro participante, o que probabelmente causará problemas de conectividade e unha alta carga nos dispositivos participantes.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "É moi recomendábel configurar unha memoria tobo distribuída cando se use Parladoiro de Nextcloud xunto cunha infraestrutura de alto rendemento.",
    "Add High-performance backend server" : "Engadir un servidor de infraestrutura de alto rendemento",
    "Warn about connectivity issues in calls with more than 2 participants" : "Avisar sobre problemas de conectividade nas chamadas con máis de 2 participantes",
    "STUN server URL" : "URL do servidor STUN",
    "The server address is invalid" : "O enderezo do servidor non é válido",
    "STUN settings saved" : "Gardáronse os axustes de STUN",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "O servidor STUN usase para determinar o enderezo IP público dos participantes que se atopan detrás dun encamiñador.",
    "Add a new STUN server" : "Engadir un novo servidor STUN",
    "{schema} scheme must be used with a domain" : "O esquema {schema} debe usarse cun dominio",
    "{option1} and {option2}" : "{option1} e {option2}",
    "{option} only" : "Só {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "Correcto: o servidor TURN devolveu satisfactoriamente candidatos ICE",
    "Error: No working ICE candidates returned by the TURN server" : "Erro: o servidor TURN non devolveu ningún candidato ICE traballando",
    "Testing whether the TURN server returns ICE candidates" : "Probe se o servidor TURN devolve candidatos ICE",
    "TURN server schemes" : "Esquemas de servidor TURN",
    "TURN server URL" : "URL do servidor TURN",
    "TURN server secret" : "Servidor TURN segredo",
    "TURN server protocols" : "Protocolos de servidor TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Utilízase un servidor TURN para proxy do tráfico dos participantes detrás dunha devasa. Se os participantes individuais non poden conectarse con outros, probabelmente sexa preciso un servidor TURN. Consulte {linkstart}esta documentación{linkend} para obter instrucións de configuración.",
    "TURN settings saved" : "Gardáronse os axustes de TURN",
    "TURN servers" : "Servidores TURN",
    "Add a new TURN server" : "Engadir un novo servidor TURN",
    "Failed" : "Fallado",
    "OK" : "Aceptar",
    "Checking …" : "Comprobando…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Fallo: WebAssembly está desactivado ou non é compatíbel neste navegador. Active WebAssembly ou utilice un navegador compatíbel con el para facer a comprobación.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Fallo: O servidor web non devolveu correctamente os ficheiros «.wasm» e «.tflite». Consulte a sección «Requisitos do sistema» na documentación de Parladoiro.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "Conforme: Os ficheiros «.wasm» e «.tflite» foron devoltos correctamente polo servidor web.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Semella que a configuración de PHP e Apache non é compatíbel. Teña en conta que PHP só se pode usar co módulo MPM_PREFORK e PHP-FPM só se pode usar co módulo MPM_EVENT.",
    "Web server setup checks" : "Comprobacións da configuración do servidor web",
    "Files required for virtual background can be loaded" : "Pódense cargar os ficheiros necesarios para o fondo virtual",
    "Federated user" : "Usuario federado",
    "Assign participants to rooms" : "Asignar participantes a salas",
    "Configure breakout rooms" : "Configurar salas parciais",
    "Number of breakout rooms" : "Número de salas parciais",
    "You can create from 1 to 20 breakout rooms." : "Vde. pode crear de 1 a 20 salas parciais.",
    "Assignment method" : "Método de asignación",
    "Automatically assign participants" : "Asignar automaticamente os participantes",
    "Manually assign participants" : "Asignar manualmente os participantes",
    "Allow participants to choose" : "Permitir que os participantes escollan",
    "Create rooms" : "Crear salas",
    "Confirm" : "Confirmar",
    "Create breakout rooms" : "Crear salas parciais",
    "Reset" : "Restabelecer",
    "Delete breakout rooms" : "Eliminar salas parciais",
    "Room {roomNumber}" : "Sala {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Perderanse as salas parciais e os axustes actuais",
    "Cancel" : "Cancelar",
    "Unassigned participants" : "Participantes sen asignar",
    "Back" : "Atrás",
    "Assign" : "Asignar",
    "Add participant \"{user}\"" : "Engadir o participante «{user}»",
    "Now" : "Agora",
    "Invalid calendar selected" : "Seleccionou un calendario incorrecto",
    "Invalid start time selected" : "Seleccionou unha hora de inicio incorrecta",
    "Invalid end time selected" : "Seleccionou unha hora de remate incorrecta",
    "Unknown error occurred" : "Produciuse un erro descoñecido",
    "Sending no invitations" : "Non enviar convites",
    "{participant0} will receive an invitation" : "{participant0} recibirá un convite",
    "{participant0} and {participant1} will receive invitations" : "{participant0} e {participant1} recibirán un convite",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} e %n máis recibirán un convite","{participant0}, {participant1} e outros %n máis recibirán un convite"],
    "Invite {user}" : "Convidar a {user}",
    "Invite all users and emails in this conversation" : "Convidar a todos os usuarios e correos-e nesta conversa",
    "Meeting created" : "Xuntanza creada",
    "Upcoming meetings" : "Próximas xuntanzas",
    "Loading …" : "Cargando…",
    "No upcoming meetings" : "Non hai xuntanzas próximas",
    "Schedule a meeting" : "Programar unha xuntanza",
    "Meeting title" : "Título da xuntanza",
    "From" : "Desde",
    "To" : "Ata",
    "Calendar" : "Calendario",
    "Attendees" : "Asistentes",
    "No other participants to send invitations to." : "Non hai outros participantes aos que enviar convites.",
    "Add attendees" : "Engadir asistentes",
    "Save" : "Gardar",
    "Search participants" : "Buscar participantes",
    "No results" : "Sen resultados",
    "Done" : "Feito",
    "Disable live transcription" : "Desactivar a transcrición en directo",
    "Disable live translation" : "Desactivar a tradución en directo",
    "Original language: {languageName}" : "Idioma orixinal ({languageName})",
    "Translated language" : "Idioma traducido",
    "Translated language: {languageName}" : "Idioma traducido ({languageName})",
    "Raise hand" : "Erguer a man",
    "Raise hand (R)" : "Erguer a man (R)",
    "Lower hand" : "Baixar a man",
    "Lower hand (R)" : "Baixar a man (R)",
    "Exit full screen (F)" : "Saír da pantalla completa (F)",
    "Full screen (F)" : "Pantalla completa (F)",
    "Speaker view" : "Vista do relator",
    "Grid view" : "Ver como grade",
    "Error when trying to load the available live transcription languages" : "Produciuse un erro ao tentar cargar os idiomas de transcrición en directo dispoñíbeis",
    "Failed to enable live transcription" : "Produciuse un fallo ao activar a transcrición en directo",
    "Failed to enable live translations" : "Produciuse un fallo ao activar a tradución en directo",
    "Failed to disable live translations" : "Produciuse un fallo ao desactivar a tradución en directo",
    "Recording consent is required" : "É necesario o consentimento para gravar",
    "This conversation is read-only" : "Esta conversa é só de lectura",
    "Conversation not found or not joined" : "Non se atopou a conversa ou non se uniu a ela",
    "Lobby is still active and you're not a moderator" : "O ástrago segue activo e Vde. non é un moderador",
    "Connection failed" : "Produciuse un fallo de conexión",
    "Reload" : "Volver cargar",
    "{nickName} raised their hand." : "{nickName} ergueu a man.",
    "A participant raised their hand." : "Un participante ergueu a man.",
    "Collapse stripe" : "Contraer pola raia",
    "Expand stripe" : "Estender a franxa",
    "Previous page of videos" : "Páxina anterior de vídeos",
    "Next page of videos" : "Seguinte páxina de vídeos",
    "Connecting …" : "Conectando…",
    "Calling …" : "Chamando…",
    "Waiting for {user} to join the call" : "Agardando a que {user} se una á chamada",
    "Waiting for others to join the call …" : "Agardando que outros se unan á chamada…",
    "You can invite others in the participant tab of the sidebar" : "Pode convidar a outros na lapela do participante da barra lateral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Pode convidar a outros na lapela do participante da barra lateral ou compartir esta ligazón para convidalos!",
    "Share this link to invite others!" : "Comparta esta ligazón para convidar a outros!",
    "Copy link" : "Copiar a ligazón",
    "You are not allowed to enable audio" : "Vde. non ten permiso para activar o son",
    "No audio. Click to select device" : "Sen son. Prema para seleccionar o dispositivo",
    "Mute audio" : "Silenciar",
    "Mute audio (M)" : "Silenciar (M)",
    "Unmute audio" : "Desactivar o silencio",
    "Unmute audio (M)" : "Desactivar o silencio (M)",
    "None" : "Ningún",
    "Select a microphone" : "Seleccione un micrófono",
    "Select a speaker" : "Seleccione un altofalante",
    "Microphone settings" : "Axustes do micrófono",
    "Check devices" : "Comprobar os dispositivos",
    "Access to camera was denied" : "Foi denegado o acceso á cámara",
    "Error while accessing camera: It is likely in use by another program" : "Produciuse un erro ao acceder á cámara: é probábel que estea en uso por outro programa",
    "Error while accessing camera" : "Produciuse un erro ao acceder á cámara",
    "You have been muted by a moderator" : "Vde. foi silenciado por un moderador",
    "Hide presenter video" : "Agochar o vídeo do presentador",
    "You are not allowed to enable video" : "Vde. non ten permiso para activar o vídeo",
    "No video. Click to select device" : "Sen vídeo. Prema para seleccionar o dispositivo",
    "Disable video" : "Desactivar o vídeo",
    "Disable video (V)" : "Desactivar o vídeo (V)",
    "Enable video" : "Activar o vídeo",
    "Enable video (V)" : "Activar o vídeo (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Activar o vídeo — A súa conexión interromperase brevemente ao activar o vídeo por primeira vez",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Activar o vídeo (V) — A súa conexión interromperase brevemente ao activar o vídeo por primeira vez",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Activar vídeo. A súa conexión será interrompida brevemente ao activar o vídeo por primeira vez",
    "Select a video device" : "Seleccione un dispositivo de vídeo",
    "Show presenter" : "Amosar o presentador",
    "You" : "Vde.",
    "Mute" : "Silenciar",
    "Muted" : "Silenciado",
    "Show screen" : "Amosar a súa pantalla",
    "Stop following" : "Deixar de seguir",
    "Connection could not be established …" : "Non foi posíbel estabelecer a conexión…",
    "Connection was lost and could not be re-established …" : "Perdeuse a conexión e non foi posíbel restabelecela…",
    "Connection could not be established. Trying again …" : "Non foi posíbel estabelecer a conexión. Tentando de novo…",
    "Connection lost. Trying to reconnect …" : "Perdeuse a conexión. Tentando conectar de novo…",
    "Connection problems …" : "Problemas de conexión…",
    "Collapse" : "Contraer",
    "Expand" : "Estender",
    "You need to be logged in to upload files" : "Ten que ter accedido para enviar ficheiros",
    "Drop your files to upload" : "Arrastre os seus ficheiros para envialos",
    "Conversation messages" : "Mensaxes de conversa",
    "Scroll to bottom" : "Desprazarse ata o final",
    "Post message" : "Publicar a mensaxe",
    "Federated conversation" : "Conversa federada",
    "Public conversation" : "Conversa pública",
    "Favorite" : "Favorito",
    "Banned users" : "Usuarios expulsados",
    "Manage the list of banned users in this conversation." : "Xestionar a lista de usuarios expulsados desta conversa.",
    "Manage bans" : "Xestionar as expulsións",
    "No banned users" : "Non hai ningún usuario expulsado",
    "Banned by:" : "Expulsado por:",
    "Date:" : "Data:",
    "Note:" : "Nota:",
    "Hide details" : "Agochar os detalles",
    "Show details" : "Amosar os detalles",
    "Unban" : "Retirar a expulsión",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Pode cambiar o título e a descrición no {linkstart}Calendario ↗{linkend}.",
    "Error while updating conversation name" : "Produciuse un erro ao actualizar o nome da conversa",
    "Error while updating conversation description" : "Produciuse un erro ao actualizar a descrición da conversa",
    "Enter a name for this conversation" : "Introduza un nome para esta conversa",
    "Edit conversation name" : "Editar o nome da conversa",
    "Edit conversation description" : "Editar a descrición da conversa",
    "Enter a description for this conversation" : "Introduza unha descrición para esta conversa",
    "Picture" : "Imaxe",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Nesta conversa é posíbel activar estes bots. Póñase en contacto coa administración da súa instancia para instalar máis bots neste servidor.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Neste servidor non hai bots instalados. Póñase en contacto coa administración da súa instancia para instalar bots neste servidor.",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Breakout rooms" : "Salas parciais",
    "Manage breakout rooms" : "Xestionar as salas parciais",
    "Set up breakout rooms for this conversation" : "Preparar as salas parciais para esta conversa",
    "Please select a valid PNG or JPG file" : "Seleccione un ficheiro PNG ou JPG válido",
    "Choose your conversation picture" : "Escolla a imaxe da súa conversa",
    "Choose" : "Escoller",
    "Error setting conversation picture" : "Produciuse un erro ao axustar a imaxe da conversa",
    "Could not set the conversation picture: {error}" : "Non foi posíbel definir a imaxe da conversa: {error}",
    "Error cropping conversation picture" : "Produciuse un erro ao recortar a imaxe da conversa",
    "Error removing conversation picture" : "Produciuse un erro ao retirar a imaxe da conversa",
    "Set emoji as conversation picture" : "Definir o «emoji» como imaxe da conversa",
    "Set background color for conversation picture" : "Definir a cor de fondo para a imaxe da conversa",
    "Upload conversation picture" : "Enviar a imaxe da conversa",
    "Choose conversation picture from files" : "Escoller a imaxe da conversa dos ficheiros",
    "Remove conversation picture" : "Retirar a imaxe da conversa",
    "The file must be a PNG or JPG" : "O ficheiro debe ser PNG ou JPG",
    "Set picture" : "Definir a imaxe",
    "Default permissions modified for {conversationName}" : "Modificáronse os permisos predeterminados para {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Non foi posíbel modificar os permisos predeterminados para {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Editar os permisos predeterminados dos participantes nesta conversa. Estes axustes non afectan aos moderadores.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Cada vez que se modifiquen os permisos nesta sección, perderanse os permisos personalizados previamente asignados aos participantes individuais.",
    "All permissions" : "Todos os permisos",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Os participantes teñen permisos para iniciar unha chamada, unirse a unha chamada, activar o son e o vídeo e compartir a pantalla.",
    "Restricted" : "Restrinxida",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Os participantes poden unirse ás chamadas, mais non poden activar o son nin o vídeo nin compartir a pantalla ata que un moderador lles conceda manualmente os permisos.",
    "Advanced permissions" : "Permisos avanzados",
    "Edit permissions" : "Editar permisos",
    "Conversation settings" : "Axustes da conversa",
    "Basic Info" : "Información básica",
    "Personal" : "Persoal",
    "Moderation" : "Moderación",
    "Setup overview" : "Vista xeral da configuración",
    "Live transcription" : "Transcrición en directo",
    "Enable live transcription" : "Activar a transcrición en directo",
    "Breakout Rooms" : "Salas parciais",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bots",
    "Danger zone" : "Zona de perigo",
    "Archive conversation" : "Arquivar a conversa",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "As conversas arquivadas agóchanse da lista de conversas de xeito predeterminado. Porén, seguirán a aparecer cando busque o nome da conversa ou acceda a unha lista de conversas arquivadas.",
    "Do you really want to leave \"{displayName}\"?" : "Confirma que quere abandonar «{displayName}»?",
    "You can archive this conversation instead." : "En troques, pode arquivar esta conversa.",
    "Leave conversation" : "Abandonar a conversa",
    "You need to promote a new moderator before you can leave the conversation" : "Debe promover un novo moderador antes de poder abandonar a conversa",
    "Delete conversation" : "Eliminar a conversa",
    "Do you really want to delete \"{displayName}\"?" : "Confirma que quere eliminar «{displayName}»?",
    "Error while deleting conversation" : "Produciuse un erro ao eliminar a conversa",
    "Delete all chat messages" : "Eliminar todas as mensaxes da parola",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Confirma que quere eliminar todas as mensaxes de «{displayName}»?",
    "Error while clearing chat history" : "Produciuse un erro ao limpar o historial da parola",
    "Be careful, these actions cannot be undone." : "Vaia a modo, estas accións non se poden desfacer.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Unha vez que se sae dunha conversación, para unirse de novo a unha conversa pechada, é necesario un convite. Pódese volver a unir a unha conversa aberta en calquera momento.",
    "Permanently delete this conversation." : "Eliminar definitivamente esta conversa.",
    "Delete chat messages" : "Eliminar as mensaxes das parolas",
    "Permanently delete all the messages in this conversation." : "Eliminar definitivamente todas as mensaxes desta conversa.",
    "_%n hour_::_%n hours_" : ["%n hora","%n horas"],
    "_%n day_::_%n days_" : ["%n día","%n días"],
    "_%n week_::_%n weeks_" : ["%n semana","%n semanas"],
    "Custom expiration time" : "Tempo de caducidade personalizado",
    "Message expiration disabled" : "Foi desactivada a caducidade da mensaxe",
    "Message expiration set: {duration}" : "Definición da caducidade da mensaxe: {duration}",
    "Error when trying to set message expiration" : "Produciuse un erro ao tentar definir a caducidade da mensaxe",
    "Message expiration" : "Caducidade da mensaxe",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "As mensaxes das parolas poden caducar após dun tempo determinado. Nota: Os ficheiros compartidos na parola non se eliminarán para o propietario, mais xa non se compartirán na conversa.",
    "Set message expiration" : "Definir a caducidade da mensaxe",
    "Current message expiration" : "Caducidade actual das mensaxes",
    "Password copied to clipboard" : "O contrasinal foi copiado no portapapeis",
    "Password could not be copied" : "Non foi posíbel copiar o contrasinal",
    "Guest access" : "Acceso de convidado",
    "Breakout rooms are not allowed in public conversations." : "Non se permiten as salas de parciais nas conversas públicas.",
    "Allow guests to join this conversation via link" : "Permite que os convidados se unan a esta conversa mediante unha ligazón",
    "Password protection" : "Protección por contrasinal",
    "This conversation is password-protected. Guests need password to join" : "Esta conversa está protexida con contrasinal. Os convidados necesitan un contrasinal para unirse",
    "Password protection is needed for public conversations" : "A protección por contrasinal é necesaria para as conversas públicas",
    "Set a password" : "Definir un contrasinal",
    "Change password" : "Cambiar o contrasinal",
    "Enter new password" : "Introduza un novo contrasinal",
    "Save password" : "Gardar o contrasinal",
    "Copy password" : "Copiar o contrasinal",
    "Guests are allowed to join this conversation via link" : "Os convidados poden unirse a esta conversa mediante a ligazón",
    "Guests are not allowed to join this conversation" : "Os convidados non poden unirse a esta conversa",
    "Resend invitations" : "Volver enviar os convites",
    "This conversation is open to both registered users and users created with the Guests app" : "Esta conversa está aberta tanto para usuarios rexistrados como para usuarios creados coa aplicación Convidados (Guests)",
    "This conversation is open to registered users" : "Esta conversa está aberta a usuarios rexistrados",
    "This conversation is limited to the current participants" : "Esta conversa está limitada aos participantes actuais",
    "You opened the conversation to both registered users and users created with the Guests app" : "Vde. abriu a conversa tanto aos usuarios rexistrados coma aos usuarios creados coa aplicación de Convidados (Guests)",
    "Error occurred when opening or limiting the conversation" : "Produciuse un erro ao abrir ou limitar a conversa",
    "Open conversation to registered users, showing it in search results" : "Abrir a conversa aos usuarios rexistrados, amosándoa nos resultados da busca",
    "Also open to users created with the Guests app" : "Aberta tamén a usuarios creados coa aplicación Convidados (Guests)",
    "Open conversation" : "Conversa aberta",
    "Set language spoken in calls" : "Definir o idioma falado nas chamadas",
    "Languages could not be loaded" : "Non foi posíbel cargar os idiomas",
    "Loading languages …" : "Cargando os idiomas…",
    "Invalid language" : "Idioma non válido",
    "Default language (English)" : "Idioma predeterminado (Inglés)",
    "Default live transcription language set" : "Definir o idioma predeterminado de transcrición en directo",
    "Live transcription language set: {languageName}" : "Idioma de transcrición en directo definido: {languageName}",
    "Error when trying to set live transcription language" : "Produciuse un erro ao tentar definir o idioma de transcrición en directo",
    "Start time: {date}" : "Hora de inicio: {data}",
    "Start time has been updated" : "Actualizouse a hora de inicio",
    "Error occurred while updating start time" : "Produciuse un erro ao actualizar a hora de inicio",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Ao activar o ástrago, os que non son moderadores serán retirados da chamada en proceso.",
    "Enable lobby, restricting the conversation to moderators" : "Activar o ástrago, limitando a conversa aos moderadores",
    "Meeting start time" : "Hora de inicio da xuntanza",
    "Start time (optional)" : "Hora de inicio (opcional)",
    "Import email participants" : "Importar participantes polo correo-e",
    "You can import a list of email participants from a CSV file." : "Pode importar unha lista de participantes polo correo-e desde un ficheiro CSV.",
    "Poll drafts" : "Borradores de enquisas",
    "Browse poll drafts" : "Examinar os borradores de enquisas",
    "Error occurred when locking the conversation" : "Produciuse un erro ao bloquear a conversa",
    "Error occurred when unlocking the conversation" : "Produciuse un erro ao desbloquear a conversa",
    "Lock conversation" : "Bloquear a conversa",
    "This will also terminate the ongoing call." : "Isto tamén rematará a chamada en proceso.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Bloquear a conversa para evitar que ninguén publique mensaxes ou inicie chamadas",
    "Edit" : "Editar",
    "More information" : "Máis información",
    "Delete" : "Eliminar",
    "Add new bridged channel to current conversation" : "Engadir unha nova canle ponte á conversa actual",
    "unknown state" : "estado descoñecido",
    "running" : "en execución",
    "not running, check Matterbridge log" : "non esta en execución, comprobe o rexistro de Matterbridge",
    "not running" : "non se está a executar",
    "Bridge saved" : "Ponte gardada",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Co Matterbridge pode pontear canles de varios sistemas de mensaxería instantánea.",
    "More info on Matterbridge" : "Máis información en Matterbridge.",
    "Messaging systems" : "Sistemas de mensaxería",
    "Enable bridge" : "Activar a ponte",
    "Show Matterbridge log" : "Amosar o rexistro do Matterbridge",
    "Log content" : "Contido do rexistro",
    "Only moderators are allowed to mention @all" : "Só a moderación pode mencionar a @todos",
    "All participants are allowed to mention @all" : "Todos os participantes poden mencionar a @todos",
    "Participants are now allowed to mention @all." : "Agora os participantes poden mencionar a @todos.",
    "Mentioning @all has been limited to moderators." : "A mención @todos foi limitada para a moderación.",
    "Allow participants to mention @all" : "Permitir que os participantes mencionen a @todos",
    "Mention permissions" : "Permisos de mención",
    "Notifications" : "Notificacións",
    "Notify about calls in this conversation" : "Notificar sobre as chamadas nesta conversa",
    "Important conversation" : "Conversa importante",
    "\"Do not disturb\" user status is ignored for important conversations" : "Nas conversas importantes, ignorarase o estado «Non molestar»",
    "Sensitive conversation" : "Conversa sensíbel",
    "Message preview will be disabled in conversation list and notifications" : "A vista previa da mensaxe estará desactivada na lista de conversas e nas notificacións",
    "Recording consent is required for calls in this conversation" : "É necesario o consentimento de gravación para as chamadas nesta conversa",
    "Recording consent is not required for calls in this conversation" : "Non é necesario o consentimento de gravación para as chamadas nesta conversa",
    "Recording consent requirement was updated" : "Actualizouse o requisito de consentimento de gravación",
    "Error occurred while updating recording consent" : "Produciuse un fallo ao actualizar o consentimento de gravación",
    "Recording Consent" : "Consentimento de gravación",
    "Recording consent cannot be changed once a call or breakout session has started." : "Non é posíbel cambiar o consentimento de gravación unha vez que se inicia unha chamada ou unha sesión parcial.",
    "Require recording consent before joining call in this conversation" : "Esixir o consentimento de gravación antes de unirse á chamada nesta conversa",
    "Recording consent is required for all calls" : "O consentimento de gravación é necesario para todas as chamadas",
    "SIP dial-in is now possible without PIN requirement" : "Agora non se precisa dun PIN para a marcación SIP",
    "SIP dial-in is now enabled" : "Agora está activada a marcación SIP",
    "SIP dial-in is now disabled" : "Agora está desactivada a marcación SIP",
    "Error occurred when enabling SIP dial-in" : "Produciuse un erro ao activar a marcación SIP",
    "Error occurred when disabling SIP dial-in" : "Produciuse un erro ao desactivar a marcación SIP",
    "Phone and SIP dial-in" : "Marcación de teléfono e SIP",
    "Enable phone and SIP dial-in" : "Activar a marcación de teléfono e SIP",
    "Allow to dial-in without a PIN" : "Permitir marcar sen PIN",
    "Ongoing" : "En proceso",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n persoa aceptou","%n persoas aceptaron"],
    "_%n person declined_::_%n people declined_" : ["%n persoa declinou","%n persoas declinaron"],
    "_and %n other attachment_::_and %n other attachments_" : ["e outro anexo","e outros %n anexos"],
    "With {displayName}" : "Con {displayName}",
    "In {conversation}" : "En {conversation}",
    "View attachment" : "Ver o anexo",
    "Join" : "Unirse",
    "View conversation" : "Ver a conversa",
    "View event on Calendar" : "Ver o evento no Calendario",
    "Error while creating the conversation" : "Produciuse un erro ao crear a conversa",
    "Hello, {displayName}" : "Ola, {displayName}",
    "Start meeting now" : "Comezar a xuntanza agora",
    "Give your meeting a title" : "Asígnelle un título á xuntanza",
    "Create and copy link" : "Crear e copiar a ligazón",
    "Create a new conversation" : "Crear unha nova conversa",
    "Join open conversations" : "Unirse a conversas abertas",
    "Call a phone number" : "Chamar a un número de teléfono",
    "Scroll backward" : "Desprazarse cara atrás",
    "Scroll forward" : "Desprazarse cara adiante",
    "Schedule meetings" : "Programar xuntanzas",
    "You don't have any upcoming meetings" : "Vde. non ten xuntanzas proximamente",
    "Open calendar" : "Abre o calendario",
    "Unread mentions" : "Mencións sen ler",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "As mensaxes nas que foi mencionado amosaranse aquí. Pode mencionar ás persoas escribindo @ seguido do seu nome",
    "Upcoming reminders" : "Próximos lembretes",
    "Message reminders" : "Lembretes de mensaxes",
    "Set a reminder on a message to be notified" : "Defina un lembrete nunha mensaxe para ser notificado",
    "Start a group conversation" : "Iniciar unha conversa en grupo",
    "Create conversation" : "Crear conversa",
    "Enter your name" : "Introduza o seu nome",
    "Submit name and join" : "Envíe o nome e únase",
    "Do you already have an account?" : "Xa ten unha conta?",
    "Log in" : "Acceder",
    "Error while verifying uploaded file" : "Produciuse un erro ao verificar o ficheiro enviado",
    "Uploaded file is verified" : "O ficheiro enviado foi verificado",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "O formato de contido é de valores separados por comas (CSV):<br/>— A liña de cabeceira é necesaria e debe coincidir con <samp>«nome»,«correo»</samp> ou só <samp>«correo»</samp><br/>— Unha entrada por liña (p. ex., <samp>«Xan Carallás»,«xan@example.tld»</samp>)",
    "Participants added successfully" : "Os participantes foron engadidos correctamente",
    "Error while adding participants" : "Produciuse un erro ao engadir os participantes",
    "Import a file" : "Importar un ficheiro",
    "Browse" : "Examinar",
    "Verifying uploaded file …" : "Verificando o ficheiro enviado…",
    "This might take a moment" : "Isto pode levar un tempo",
    "Send invitations" : "Enviando os convites",
    "_%n invalid email_::_%n invalid emails_" : ["%n correo non válido","%n correos non válidos"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n correos xa foi importado ou duplicado","%n correos xa foron importados ou duplicados"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["Enviouse %n convite","Enviáronse %n convites"],
    "An error occurred while calling a phone number" : "Produciuse un erro ao chamar a un número de teléfono",
    "Phone number could not be called: {error}" : "Non foi posíbel chamar ao número de teléfono: {error}",
    "Phone number could not be called" : "Non foi posíbel chamar ao número de teléfono",
    "Search participants or phone numbers" : "Buscar participantes ou números de teléfono",
    "Creating the conversation …" : "Creando a conversa…",
    "Mark as read" : "Marcar como lido",
    "Mark as unread" : "Marcar como sen ler",
    "Remove from favorites" : "Retirar de favoritos",
    "Add to favorites" : "Engadir a favoritos",
    "Unarchive conversation" : "Desarquivar a conversa",
    "Ignore \"Do not disturb\"" : "Ignorar «Non molestar»",
    "You need to promote a new moderator before you can leave the conversation." : "Debe promover un novo moderador antes de poder abandonar a conversa.",
    "Conversation actions" : "Accións de conversa",
    "Notify about calls" : "Notificar sobre as chamadas",
    "Hide message text" : "Agochar o texto da mensaxe",
    "Pending invitations" : "Convites pendentes",
    "From {user} at {remoteServer}" : "De {user} en {remoteServer}",
    "Decline invitation" : "Declinar o convite",
    "Accept invitation" : "Aceptar o convite",
    "No pending invitations" : "Non hai convites pendentes",
    "Home" : "Inicio",
    "Unread" : "Sen ler",
    "Mentions" : "Mencións",
    "Meetings" : "Xuntanzas",
    "Alphabetically" : "Alfabeticamente",
    "No followed threads" : "Ningún fío seguido",
    "No matches found" : "Non se atopou ningunha coincidencia",
    "No conversations found" : "Non se atopou ningunha conversa",
    "You have no archived conversations." : "Vde. non ten conversas arquivadas.",
    "Subscribe to an existing thread or start your own." : "Subscríbase a un fío existente ou inicie un propio",
    "You have no unread mentions." : "Vde. non ten mencións sen ler.",
    "You have no unread messages." : "Vde. non ten mensaxes sen ler.",
    "An error occurred while performing the search" : "Produciuse un erro ao realizar a busca",
    "Conversation list" : "Lista de conversas",
    "Filter conversations by" : "Filtrar conversas por",
    "Unread messages" : "Mensaxes sen ler",
    "Meeting conversations" : "Conversas das xuntanzas",
    "Clear filters" : "Limpar os filtros",
    "New personal note" : "Nova nota persoal",
    "Back to conversations" : "Volver ás conversas",
    "Archived conversations" : "Conversas arquivadas",
    "Threads" : "Fíos",
    "Clear filter" : "Limpar o filtro",
    "Show more threads" : "Amosar máis fíos",
    "App settings" : "Axustes da aplicación",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Teams" : "Equipos",
    "Federated users" : "Usuarios federados",
    "New private conversation" : "Nova conversa privada",
    "Other sources" : "Outras orixes",
    "Open conversations" : "Conversas abertas",
    "No search results" : "Sen resultados de busca",
    "Users, groups and teams" : "Usuarios, grupos e equipos",
    "Users and groups" : "Usuarios e grupos",
    "Users and teams" : "Usuarios e equipos",
    "Groups and teams" : "Grupos e equipos",
    "New group conversation" : "Nova conversa en grupo",
    "The meeting will start soon" : "A xuntanza comezará decontado",
    "This meeting is scheduled for {startTime}" : "Esta xuntanza está programada para as {startTime}",
    "You are currently waiting in the lobby" : "Agora está agardando no ástrago.",
    "Enable noise suppression" : "Activar a supresión do ruído",
    "Reduce background noises for better voice quality" : "Reducir os ruídos de fondo para mellorar a calidade da voz",
    "Enable echo cancellation" : "Activar cancelación de eco",
    "Minimize echo effect from own surrounding" : "Minimizar o efecto de eco do seu propio contorno",
    "Enable auto gain control" : "Activar o control automático de ganancia",
    "Dynamically adjust microphone volume for consistent level" : "Axusta dinamicamente o volume do micrófono para un nivel constante",
    "Select microphone" : "Seleccione o micrófono",
    "No microphone available" : "Non hai micrófonos dispoñíbeis",
    "Select speaker" : "Seleccione o altofalante",
    "No speaker available" : "Non hai ningún altofalante dispoñíbel",
    "Select camera" : "Seleccione a cámara",
    "No camera available" : "Non hai cámaras dispoñíbeis",
    "Select a device" : "Seleccione un dispositivo",
    "Playing …" : "Reproducindo…",
    "Test speakers" : "Probar os altofalantes",
    "Test" : "Proba",
    "Devices" : "Dispositivos",
    "Backgrounds" : "Fondos",
    "No audio" : "Sen son",
    "No camera" : "Sen cámara",
    "Display video as you will see it (mirrored)" : "Amosa o vídeo tal e como o verá (reflectido)",
    "Display video as others will see it" : "Amosa o vídeo tal e como o verán os demais",
    "Calls are not supported in your browser" : "O seu navegador non admite chamadas",
    "Access to microphone is only possible with HTTPS" : "O acceso ao micrófono só é posíbel con HTTPS",
    "Access to microphone was denied" : "Foi denegado o acceso ao micrófono",
    "Error while accessing microphone" : "Produciuse un erro ao acceder ao micrófono",
    "Access to camera is only possible with HTTPS" : "O acceso á cámara só é posíbel con HTTPS",
    "The call is being recorded." : "Estase a gravar a chamada.",
    "The call might be recorded." : "É posíbel que a chamada sexa gravada.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "A gravación pode incluír a súa voz, o vídeo da cámara e da pantalla compartida. É preciso o seu consentimento antes de unirse á chamada.",
    "Give consent to the recording of this call" : "Dar consentimento para a gravación desta chamada",
    "Show more info" : "Amosar máis información",
    "Audio is not available" : "O son non está dispoñíbel",
    "Video is not available" : "O vídeo non está dispoñíbel",
    "Start recording immediately with the call" : "Comezar a gravar inmediatamente coa chamada",
    "Notify all participants about this call" : "Notificar a todos os participantes sobre esta chamada",
    "Apply settings" : "Aplicar os axustes",
    "Select virtual office background" : "Seleccione o fondo virtual de oficina",
    "Select virtual home background" : "Seleccione o fondo virtual de vivenda",
    "Select virtual abstract background" : "Seleccione o fondo virtual abstracto",
    "Select virtual beach background" : "Seleccione o fondo virtual de praia",
    "Select virtual park background" : "Seleccione o fondo virtual de parque",
    "Select virtual theater background" : "Seleccione o fondo virtual de teatro",
    "Select virtual library background" : "Seleccione o fondo virtual de biblioteca",
    "Select virtual space station background" : "Seleccione o fondo virtual de estación espacial",
    "Error while uploading the file" : "Produciuse un erro ao enviar o ficheiro",
    "Select a file" : "Seleccione un ficheiro",
    "Invalid path selected" : "Seleccionou unha ruta incorrecta.",
    "Select virtual background from file {fileName}" : "Seleccione un fondo virtual desde o ficheiro {fileName}",
    "Blur" : "Esvaer",
    "Upload" : "Enviar",
    "Files" : "Ficheiros",
    "(editing)" : "(editando)",
    "(edited)" : "(editado)",
    "The message has expired or has been deleted" : "A mensaxe caducou ou foi eliminada",
    "Cancel quote" : "Cancelar a mención",
    "24 hours" : "24 horas",
    "7 days" : "7 días",
    "30 days" : "30 días",
    "Until unpin" : "Ata que se desprenda",
    "Clear reminder – {timeLocale}" : "Limpar o lembrete – {timeLocale}",
    "Edited by {actor}" : "Editado por {actor}",
    "Pinned by you" : "Fixado por vostede",
    "Pinned by {actor}" : "Fixado por {actor}",
    "Until {absoluteDate}" : "Ata {absoluteDate}",
    "Message text copied to clipboard" : "Copiouse o texto da mensaxe no portapapeis",
    "Message text could not be copied" : "Non foi posíbel copiar o texto da mensaxe",
    "Message forwarded to \"Note to self\"" : "Reenviouse a mensaxe a «Notas para un mesmo»",
    "Error while forwarding message to \"Note to self\"" : "Produciuse un erro ao reenviar a mensaxe a «Notas para un mesmo»",
    "A reminder was successfully removed" : "Retirouse correctamente un lembrete",
    "Error occurred when removing a reminder" : "Produciuse un erro ao retirar un lembrete",
    "A reminder was successfully set at {datetime}" : "Definiuse correctamente un lembrete para {datetime}",
    "Error occurred when creating a reminder" : "Produciuse un erro ao crear un lembrete",
    "Add a reaction to this message" : "Engadir unha reacción a esta mensaxe",
    "Reply" : "Responder",
    "More actions" : "Máis accións",
    "Set reminder" : "Definir un lembrete",
    "Pin message" : "Fixar a mensaxe",
    "Unpin message" : "Desprender a mensaxe",
    "Reply privately" : "Responder en privado",
    "Edit message" : "Editar a mensaxe",
    "Copy message" : "Copiar a mensaxe",
    "Copy message link" : "Copiar a ligazón da mensaxe",
    "Go to file" : "Ir ao ficheiro",
    "Download file" : "Descargar ficheiro",
    "Go to thread" : "Ir ao fío",
    "Edit thread details" : "Editar os detalles do fío",
    "Forward message" : "Reenviar mensaxe",
    "Translate" : "Traducir",
    "Set custom reminder" : "Definir un lembrete personalizado",
    "Keep pinned for" : "Manter fixado para",
    "Set custom period" : "Definir un período personalizado",
    "Close reactions menu" : "Pechar o menú de reaccións",
    "React with {emoji}" : "Reaccionar con {emoji}",
    "React with another emoji" : "Reaccionar con outro «emoji»",
    "Choose a conversation to forward the selected message." : "Escolla unha conversa a que reenviar a mensaxe seleccionada.",
    "Error while forwarding message" : "Produciuse un erro ao reenviar a mensaxe",
    "The message has been forwarded to {selectedConversationName}" : "A mensaxe foi reenviada a {selectedConversationName}",
    "Dismiss" : "Rexeitar",
    "Go to conversation" : "Ir á conversa",
    "Detect language" : "Detectar o idioma",
    "The message could not be translated" : "Non foi posíbel traducir a mensaxe",
    "Translation copied to clipboard" : "A tradución foi copiada no portapapeis.",
    "Translation could not be copied" : "Non foi posíbel copiar a tradución",
    "Translate message" : "Traducir a mensaxe",
    "Source language to translate from" : "Idioma de orixe do que traducir",
    "Translate from" : "Traducir desde",
    "Target language to translate into" : "Idioma de destino ao que traducir",
    "Translate to" : "Traducir a",
    "Translating" : "Traducindo",
    "Copy translated text" : "Copiar o texto traducido",
    "Error when scheduling the message" : "Produciuse un erro ao programar a mensaxe",
    "Reschedule" : "Reprogramar",
    "Send now" : "Enviar agora",
    "Choose a time" : "Escolla unha hora",
    "Send at custom time" : "Enviar a unha hora personalizada",
    "Will be sent without notification" : "Enviarase sen notificación",
    "Message read by everyone who shares their reading status" : "Mensaxe lida por todos os que comparten o seu estado de lectura",
    "Message sent" : "Mensaxe enviada",
    "Sent without notification" : "Enviar sen notificación",
    "Deleting message" : "Eliminando a mensaxe",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "A mensaxe foi eliminada correctamente, mais está configurado un bot ou Matterbridge e a mensaxe podería estar xa distribuída a outros servizos",
    "Message deleted successfully" : "A mensaxe foi eliminada satisfactoriamente",
    "Message could not be deleted because it is too old" : "Non foi posíbel eliminar a mensaxe porque é demasiado antiga",
    "Only normal chat messages can be deleted" : "Só é posíbel eliminar as mensaxes normais da parola",
    "An error occurred while deleting the message" : "Produciuse un erro ao eliminar a mensaxe",
    "Pinned" : "Fixada",
    "Your browser does not support playing audio files" : "O seu navegador non admite a reprodución de ficheiros de son",
    "Contact" : "Contacto",
    "{stack} in {board}" : "{stack} en {board}",
    "Deck Card" : "Tarxeta de Gabeta",
    "Remove {fileName}" : "Retirar {fileName}",
    "Open this location in OpenStreetMap" : "Abrir esta localización en OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n resposta","%n respostas"],
    "Sending message" : "Enviando a mensaxe",
    "Failed to send the message. Click to try again" : "Produciuse un fallo ao enviar a mensaxe. Prema para tentalo de novo",
    "Not enough free space to upload file" : "Non hai espazo libre abondo para enviar un ficheiro",
    "You cannot send messages to this conversation at the moment" : "Non pode enviar mensaxes a esta conversa polo momento",
    "Could not update the message" : "Non foi posíbel actualizar a mensaxe",
    "Reply to thread \"{threadTitle}\"" : "Responder ao fío «{threadTitle}»",
    "You voted" : "Votou",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Borrador da enquisa • %n opción","Borrador da enquisa • %n opcións"],
    "_%n vote_::_%n votes_" : ["%n voto","%n votos"],
    "Edit poll draft" : "Editar o borrador da enquisa",
    "Delete poll draft" : "Eliminar o borrador da enquisa",
    "Open poll" : "Enquisa aberta",
    "See results" : "Ver os resultados",
    "Reactions" : "Reaccións",
    "No permission to post reactions in this conversation" : "Non ten permiso para publicar reaccións nesta conversa",
    "and {participant}" : "e {participant}",
    "_and %n other participant_::_and %n other participants_" : ["e outro participante","e outros %n participantes"],
    "Show all reactions" : "Amosar todas as reaccións",
    "Add more reactions" : "Engadir máis reaccións",
    "Show or collapse system messages" : "Amosar ou contraer as mensaxes do sistema",
    "No messages" : "Non hai mensaxes",
    "All messages have expired or have been deleted." : "Todas as mensaxes caducaron ou foron eliminadas.",
    "{author} (pinned by you)" : "{author} (fixada por vostede)",
    "{author} (pinned by {actor})" : "{author} (fixada por {actor})",
    "Unpin" : "Desprender",
    "Cancel search" : "Cancelar a busca",
    "Add a phone number" : "Engadir un número de teléfono",
    "Error: A password is required to create the conversation." : "Erro: é necesario un contrasinal para crear a conversa.",
    "All set, the conversation \"{conversationName}\" was created." : "Todo listo, creouse a conversa «{conversationName}».",
    "Create a new group conversation" : "Crear unha nova conversa en grupo",
    "Add participants" : "Engadir participantes",
    "Maximum length exceeded ({maxlength} characters)" : "Excedeuse a lonxitude máxima ({maxlength} caracteres)",
    "Conversation visibility" : "Visibilidade da conversa",
    "Allow guests to join via link" : "Permitir que os convidados se unan a través de ligazón",
    "Enter password" : "Introduza o contrasinal",
    "This conversation has been locked" : "Esta conversa foi bloqueada",
    "No permission to post messages in this conversation" : "Non ten permiso para publicar mensaxes nesta conversa",
    "Joining conversation …" : "Uníndose á conversa…",
    "Write a message without notification" : "Escribir unha mensaxe sen notificación",
    "Create a thread silently" : "Crear un fío de xeito silandeiro",
    "Create a thread" : "Crear un fío",
    "Send message silently" : "Enviar unha mensaxe silandeira",
    "Send message" : "Enviar a mensaxe",
    "Send without notification" : "Enviar sen notificación",
    "The participant will not be notified about new messages" : "O participante non recibirá notificacións sobre novas mensaxes",
    "Participants will not be notified about new messages" : "Os participantes non recibirán notificacións sobre novas mensaxes",
    "Message will be sent {datetimeString}" : "A mensaxe enviarase o/ás {datetimeString}",
    "Thread title is required" : "Precisase un título para o fío",
    "Message text is required" : "Precisase o texto da mensaxe",
    "The message could not be edited" : "Non foi posíbel editar a mensaxe",
    "File to share" : "Ficheiro para compartir",
    "File upload is not available in this conversation" : "O envío de ficheiros non está dispoñíbel nesta conversa",
    "Message was successfully scheduled" : "A mensaxe foi programada satisfactoriamente",
    "Add emoji" : "Engadir un «emoji»",
    "Adding a mention will only notify users who did not read the message." : "Engadir unha mención só notificará aos usuarios que non leron a mensaxe.",
    "Thread title" : "Título do fío",
    "Send later" : "Enviar máis tarde",
    "Show scheduled messages" : "Amosar as mensaxes programadas",
    "Cancel editing" : "Cancelar a edición",
    "Schedule message" : "Mensaxe programada",
    "{user} is out of office and might not respond." : "{usuario} está fóra da oficina e é posíbel que non responda.",
    "Absence period: {startDate} - {endDate}" : "Período de ausencia: {startDate} — {endDate}",
    "Replacement:" : "Substitución:",
    "Share from {nextcloud}" : "Compartir desde {nextcloud}",
    "Share from Files" : "Compartir desde «Ficheiros»",
    "Share files to the conversation" : "Compartir ficheiros na conversa",
    "Upload from device" : "Enviar desde o dispositivo",
    "Create new poll" : "Crear unha enquisa nova",
    "Smart picker" : "Selector intelixente",
    "Record voice message" : "Gravar mensaxe de voz",
    "End recording and send" : "Finalizar a gravación e enviar",
    "Dismiss recording" : "Rexeitar a gravación",
    "Access to the microphone was denied" : "Foi denegado o acceso ao micrófono",
    "Microphone either not available or disabled in settings" : "O micrófono non está dispoñíbel ou está desactivado nos axustes",
    "Error while recording audio" : "Produciuse un erro ao gravar o son",
    "Generating summary of unread messages …" : "Xerando un resumo das mensaxes sen ler…",
    "Summary is AI generated and might contain mistakes" : "O resumo é xerado por IA e pode conter erros",
    "Error occurred during a summary generation" : "Produciuse un erro durante a xeración dun resumo",
    "New file" : "Novo ficheiro",
    "Blank" : "Baleiro",
    "Error while creating file" : "Produciuse un erro ao crear o ficheiro",
    "Create and share a new file" : "Crear e compartir un ficheiro novo",
    "Name of the new file" : "Nome do novo ficheiro",
    "Create file" : "Crear ficheiro",
    "Someone is typing …" : "Alguén está escribindo…",
    "{user1} is typing …" : " {user1} está escribindo…",
    "{user1} and {user2} are typing …" : " {user1} e {user2} están escribindo…",
    "{user1}, {user2} and {user3} are typing …" : " {user1}, {user2} e {user3} están escribindo…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : [" {user1}, {user2}, {user3} e %n máis están escribindo…"," {user1}, {user2}, {user3} e outros %n están escribindo…"],
    "Add more files" : "Engadir máis ficheiros",
    "Send" : "Enviar",
    "In this conversation <strong>{user}</strong> can:" : "Nesta conversa <strong>{user}</strong> pode:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Editar os permisos predeterminados dos participantes en <strong>{conversationName}</strong>",
    "Start a call" : "Iniciar unha chamada",
    "Skip the lobby" : "Saltarse o ástrago",
    "Can post messages" : "Pode publicar mensaxes",
    "Can post messages and reactions" : "Pode publicar mensaxes e reaccións",
    "Can add reactions" : "Pode engadir reaccións",
    "Enable the microphone" : "Activar o micrófono",
    "Enable the camera" : "Activar a cámara",
    "Share the screen" : "Compartir a pantalla",
    "Update permissions" : "Actualizar os permisos",
    "Updating permissions" : "Actualizando os permisos",
    "No poll drafts" : "Non hai ningún borrador de enquisa",
    "There is no poll drafts yet saved for this conversation" : "Aínda non hai ningún borrador de enquisa gardado para esta conversa",
    "Create poll in {name}" : "Crear enquisa en {name}",
    "Create poll" : "Crear enquisa",
    "Error while importing poll" : "Produciuse un erro ao importar a enquisa",
    "Question" : "Pregunta",
    "Ask a question" : "Facer unha pregunta",
    "Import draft from file" : "Importar o borrador do ficheiro",
    "Answers" : "Respostas",
    "Answer {option}" : "Resposta {option}",
    "Delete poll option" : "Eliminar opción de enquisa",
    "Add answer" : "Engadir a resposta",
    "Settings" : "Axustes",
    "Anonymous poll" : "Enquisa anónima",
    "Multiple answers" : "Varias respostas",
    "Save as draft" : "Gardar como borrador",
    "Export draft to file" : "Exportar o borrador ao ficheiro",
    "You voted for this option" : "Vde. votou por esta opción",
    "End poll" : "Finalizar a enquisa",
    "Change your vote" : "Cambiar o seu voto",
    "Results" : "Resultados",
    "Voted participants" : "Participantes votados",
    "Send a message to \"{roomName}\"" : "Enviar unha mensaxe a «{roomName}»",
    "Hide list of participants" : "Agochar a lista de participantes",
    "Show list of participants" : "Amosar a lista de participantes",
    "Assistance requested in {roomName}" : "Solicitouse asistancia en {roomName}",
    "The message was sent to \"{roomName}\"" : "A mensaxe foi enviada a «{roomName}»",
    "Dismiss request for assistance" : "Rexeitar a solicitude de axuda",
    "Send message to room" : "Enviar mensaxe á sala",
    "Back to main room" : "Volver á sala principal",
    "Back to your room" : "Volver á súa sala",
    "Message all rooms" : "Mensaxes a todas as salas",
    "Start session" : "Iniciar sesión",
    "Start a call before you start a breakout room session" : "Iniciar unha chamada antes de iniciar unha sesión en sala parcial",
    "Stop session" : "Deter a sesión",
    "The message was sent to all breakout rooms" : "A mensaxe foi enviada a todas as salas parciais",
    "Send a message to all breakout rooms" : "Enviar unha mensaxe a todas as salas parciais",
    "Breakout rooms are not started" : "Non se iniciaron as salas parciais",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "As chamadas sen infraestrutura de alto rendemento poden causar problemas de conectividade e provocar unha carga moi alta nos dispositivos. {linkstart}Máis información{linkend}",
    "Talk setup incomplete" : "Configuración de Parladoiro incompleta",
    "Disable lobby" : "Desactivar o ástrago",
    "Settings for participant \"{user}\"" : "Axustes para o participante «{user}»",
    "Participant \"{user}\"" : "Participante «{user}»",
    "moderator" : "moderador",
    "bot" : "bot",
    "guest" : "convidado",
    "Ringing …" : "Soando…",
    "Call rejected" : "Chamada rexeitada",
    "{time} talking …" : "{time} falando…",
    "{time} talking time" : "Tempo de conversa: {time}",
    "Raised their hand" : "Ergueron a man",
    "Joined with video" : "Uniuse con vídeo",
    "Joined via phone" : "Uniuse a través do teléfono",
    "Joined with audio" : "Uniuse con son",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "O texto debe ser menor ou igual a {maxLength} caracteres. O seu texto actual ten {charactersCount} caracteres.",
    "Remove group and members" : "Retirar grupo e membros",
    "Remove team and members" : "Retirar equipo e membros",
    "Remove participant" : "Retirar participante",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Confirma que quere retirar o grupo «{displayName}» e os seus membros desta conversa?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Confirma que quere retirar o equipo «{displayName}» e os seus membros desta conversa?",
    "Do you really want to remove {displayName} from this conversation?" : "Confirma que quere retirar a {displayName} desta conversa?",
    "Notification was sent to {displayName}" : "Enviouse a notificación a {displayName}",
    "Could not send notification to {displayName}" : "Non foi posíbel enviar a notificación a {displayName}",
    "Permissions granted to {displayName}" : "Concedéronse os permisos a {displayName}",
    "Could not modify permissions for {displayName}" : "Non foi posíbel modificar os permisos de {displayName}",
    "Permissions removed for {displayName}" : "Retiráronse os permisos de {displayName}",
    "Permissions set to default for {displayName}" : "Permisos estabelecidos como predeterminados para {displayName}",
    "Phone number could not be hung up" : "Non foi posíbel colgar o número de teléfono",
    "Phone number could not be put on hold" : "Non foi posíbel por en espera o número de teléfono",
    "Phone number could not be muted" : "Non foi posíbel silenciar o número de teléfono",
    "Phone number could not be unmuted" : "Non foi posíbel desactivar o silencio ao número de teléfono",
    "DTMF message could not be sent" : "Non foi posíbel enviar a mensaxe DTMF",
    "Phone number copied to clipboard" : "Número de teléfono copiado no portapapeis",
    "Phone number could not be copied" : "Non foi posíbel copiar o número de teléfono",
    "in the lobby" : "no ástrago",
    "Dial out phone" : "Marcar o número de teléfono",
    "Hang up phone" : "Colgar o teléfono",
    "Move back to lobby" : "Volver ao ástrago",
    "Move to conversation" : "Mover á conversa",
    "Dial-in PIN" : "PIN de marcación",
    "Demote from moderator" : "Relegar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Resend invitation" : "Volver enviar o convite",
    "Send call notification" : "Enviar notificación de chamada",
    "Dial out phone number" : "Marcar o número de teléfono",
    "Resume call for phone number" : "Retomar a chamada para o número de teléfono",
    "Put phone number on hold" : "Poñer o número de teléfono en espera",
    "Unmute phone number" : "Desactivar o silencio ao número de teléfono",
    "Mute phone number" : "Silenciar o número de teléfono",
    "Copy phone number" : "Copiar o número de teléfono",
    "Reset custom permissions" : "Restabelecer os permisos personalizados",
    "Grant all permissions" : "Conceder todos os permisos",
    "Remove all permissions" : "Retirar todos os permisos",
    "Also ban from this conversation" : "Expulsar tamén desta conversa",
    "Internal note (reason to ban)" : "Nota interna (motivo da expulsión)",
    "Remove" : "Retirar",
    "Permissions modified for {displayName}" : "Modificáronse os permisos de {displayName}",
    "Add users, groups or teams" : "Engadir usuarios, grupos ou equipos",
    "Add users or groups" : "Engadir usuarios ou grupos",
    "Add users or teams" : "Engadir usuarios ou equipos",
    "Add users" : "Engadir usuarios",
    "Add groups or teams" : "Engadir grupos ou equipos",
    "Add groups" : "Engadir grupos",
    "Add teams" : "Engadir equipos",
    "Add other sources" : "Engadir outras orixes",
    "Add emails" : "Engadir correos",
    "Integrations" : "Integracións",
    "Add federated users" : "Engadir usuarios federados",
    "Searching …" : "Buscando…",
    "Search for more users" : "Buscar máis usuarios",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Pode buscar ou engadir participantes a través do seu nome, correo-e ou ID de nube federada",
    "Search or add participants" : "Buscar ou engadir participantes",
    "Invitation was sent to {actorId}" : "Enviouse o convite a {actorId}",
    "An error occurred while adding the participants" : "Produciuse un erro ao engdir os participantes",
    "A new group conversation with selected participant will be created" : "Crearase unha nova conversa de grupo co participante seleccionado",
    "Participants" : "Participantes",
    "Pinned by a deleted user" : "Fixado por un usuario eliminado",
    "Participants ({count})" : "Participantes ({count})",
    "Open chat" : "Abrir unha parola",
    "You have new unread messages in the chat." : "Ten novas mensaxes sen ler na parola",
    "You have been mentioned in the chat." : "Mencionárono na parola.",
    "Search messages" : "Buscar mensaxes",
    "Chat" : "Parola",
    "Details" : "Detalles",
    "Shared items" : "Elementos compartidos",
    "Search in {name}" : "Buscar en {name}",
    "Threads in {name}" : "Fíos en {name}",
    "{actor} in {conversation}" : "{actor} en {conversation}",
    "Search messages …" : "Buscar mensaxes…",
    "Search options" : "Opcións de busca",
    "From User" : "Desde o usuario",
    "Since" : "Desde",
    "Until" : "Ata",
    "No results found" : "Non se atopou ningún resultado",
    "Load more results" : "Cargando máis resultados",
    "Recent threads" : "Fíos recentes",
    "Projects" : "Proxectos",
    "No shared items" : "Non hai elementos compartidos",
    "Thread notifications" : "Notificacións de fíos",
    "Thread actions" : "Accións do fío",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Ligazón a unha conversa",
    "No open conversations found" : "Non se atopou ningunha conversa aberta",
    "Either there are no open conversations or you joined all of them." : "Ou non hai conversas abertas ou uniuse a todas.",
    "Check spelling or use complete words." : "Revise a ortografía ou use palabras completas.",
    "Search conversations or users" : "Buscar conversas ou usuarios",
    "Select conversation" : "Seleccionar conversa",
    "Number length is not valid" : "A lonxitude do número non é correcta",
    "Region code is not valid" : "O código de área non é correcto",
    "Number length is too short" : "O número é demasiado curto",
    "Number length is too long" : "O número é demasiado longo",
    "Number is not valid" : "O número non é correcto",
    "Phone numbers" : "Números de teléfono",
    "Display name: {name}" : "Nome para amosar: {name}",
    "Edit display name" : "Editar o nome para amosar",
    "Display name (required)" : "Nome para amosar (necesario)",
    "Save name" : "Gardar o nome",
    "I picked message bubbles" : "Escollín globos de mensaxe",
    "Error while setting personal setting" : "Produciuse un erro ao gardar o axuste persoal",
    "Error while saving sounds setting" : "Produciuse un erro ao gardar os axustes de son",
    "Compact conversations list" : "Lista compacta de conversas",
    "Chat appearance" : "Aparencia da parola",
    "Messages list" : "Lista de mensaxes",
    "Message bubbles" : "Globos de mensaxe",
    "Play sounds when participants join or leave a call" : "Reproducir sons cando os participantes se unan ou abandonen unha chamada",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Actualmente non está dispoñíbel para iPhone e iPad por mor das restricións técnicas do fabricante",
    "Notification settings" : "Axustes de notificación",
    "Sounds for chat and call notifications" : "Sons para notificacións de parola e chamadas",
    "Invalid language ({languageId})" : "Idioma non válido {languageId}",
    "Default language" : "Idioma predeterminado",
    "Default language ({languageName})" : "Idioma predeterminado ({languageName})",
    "Error when trying to load the available live translation languages" : "Produciuse un erro ao tentar cargar os idiomas de tradución en directo dispoñíbeis",
    "Error when trying to set live translation language" : "Produciuse un erro ao tentar definir o idioma de tradución en directo",
    "Set language used to show the transcriptions" : "Definir o idioma empregado para amosar as transcricións",
    "Select location for attachments" : "Seleccionar a localización dos ficheiros anexos",
    "Error while setting attachment folder" : "Produciuse un erro ao axustar o cartafol de anexos",
    "Error while setting read status privacy" : "Produciuse un erro ao axustar a privacidade do estado de lectura",
    "Error while setting typing status privacy" : "Produciuse un erro ao axustar a privacidade do estado de escritura",
    "Error while setting default media state" : "Produciuse un erro ao axustar o estado multimedia predeterminado",
    "Turn camera and microphone off by default" : "Desactivar a cámara e o micrófono de xeito predeterminado",
    "Blur camera background by default" : "Desenfocar o fondo da cámara de xeito predeterminado",
    "Skip device preview before joining a call" : "Omitir a vista previa do dispositivo antes de unirse a unha chamada",
    "Appearance & Sounds" : "Aparencia e sons",
    "Privacy" : "Privacidade",
    "Send read receipts" : "Enviar acuses de recibimento",
    "When off, all read statuses will be hidden" : "Cando estea desactivado, agocharanse todos os estados de lectura",
    "Share typing status" : "Compartir o estado de escritura",
    "When off, all typing indicators will be hidden" : "Cando estea desactivado, agocharanse todos os indicadores de escritura",
    "Attachments folder" : "Cartafol de anexos",
    "Toggle full screen" : "Alternar a pantalla completa",
    "Return to Home screen" : "Volver á pantalla de inicio",
    "Search" : "Buscar",
    "Shortcuts while in a chat" : "Atallos nunha parola",
    "Focus the chat input" : "Poñer en foco a entrada da parola",
    "Unfocus the chat input to use shortcuts" : "Retirar do foco a entrada da parola para usar atallos",
    "Edit your last message" : "Editar a súa última mensaxe",
    "Shortcuts while in a call" : "Atallos nunha chamada",
    "Camera on and off" : "Acendido e apagado da cámara",
    "Microphone on and off" : "Acendido e apagado do micrófono",
    "Raise or lower hand" : "Erguer ou baixar a man",
    "Push to talk or push to mute" : "Premer para falar ou premer para silenciar",
    "Zoom-in / zoom-out a screen share" : "Achegar/afastar a pantalla compartida",
    "Mouse wheel" : "Roda do rato",
    "Start call silently" : "Comezar a chamada silandeiramente",
    "Start call" : "Iniciar chamada",
    "End call" : "Finalizar a chamada",
    "This call has just ended" : "Esta chamada ven de rematar",
    "You will be able to join the call only after a moderator starts it." : "Só poderá unirse á chamada após que a inicie un moderador.",
    "End call for everyone" : "Finalizar a chamada para todos",
    "Starting the recording" : "Iniciando a gravación",
    "Recording" : "Gravando",
    "The call has been running for one hour." : "A chamada leva unha hora en proceso.",
    "Cancel recording start" : "Cancelar o inicio da gravación",
    "Stop recording" : "Deter a gravación",
    "Send a reaction" : "Envíar unha reacción",
    "React with {reaction}" : "Reaccionar con {reacción}",
    "All tasks done!" : "Feitas todas as tarefas!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} de %n tarefa","{done} de %n tarefas"],
    "Add participants to this call" : "Engadir participantes a esta chamada",
    "_%n participant in call_::_%n participants in call_" : ["%n  participante na chamada","%n participantes na chamada"],
    "Scheduled messages" : "Mensaxes programadas",
    "You are not allowed to enable screensharing" : "Non ten permiso para activar o uso compartido de pantalla",
    "No screensharing" : "Non hai uso compartido de pantalla",
    "Screensharing options" : "Opcións para compartir pantalla",
    "Enable screensharing" : "Activar a compartición da pantalla",
    "Bad sent video and screen quality." : "Mala calidade de vídeo e pantalla enviados.",
    "Bad sent screen quality." : "Mala calidade de pantalla enviada.",
    "Bad sent video quality." : "Mala calidade do vídeo enviado.",
    "Bad sent audio, video and screen quality." : "Mala calidade do son, vídeo e pantalla enviados.",
    "Bad sent audio and screen quality." : "Mala calidade do son e da pantalla enviados.",
    "Bad sent audio and video quality." : "Mala calidade do son e vídeo enviados.",
    "Bad sent audio quality." : "Mala calidade do son enviado.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Ou súa conexión a Internet ou o seu computador están ocupados e é posíbel que outros participantes non poidan ver a súa pantalla. Para mellorar a situación, tente desactivar o esvaemento do fondo ou do seu vídeo mentres comparte a pantalla.",
    "Disable background blur" : "Desactivar o esvaemento do fondo",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Ou a súa conexión a Internet ou o computador están ocupados e pode que outros participantes non sexan quen de ver a súa pantalla. Para mellorar a situación, tente desactivar o seu vídeo mentres comparte a pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Ou a súa conexión a internet ou o computador están ocupados e pode que outros participantes non poidan ver a súa pantalla. ",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Ou a súa conexión a internet ou o computador están ocupados e pode que outros participantes non poidan velo.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Ou súa conexión a Internet ou o seu computador están ocupados e é posíbel que outros participantes non sexan quen de entendelo nin velo. Para mellorar a situación, tente desactivar o esvaemento do fondo ou do seu vídeo mentres comparte a pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Ou a súa conexión a internet ou o computador están ocupados e pode que outros participantes non sexan quen de entendelo e velo. Para mellorar a situación, tente desactivar o seu vídeo mentres comparte a pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Ou a súa conexión a internet ou o computador están ocupados e pode que outros participantes non sexan quen de entendelo e ver a súa pantalla. Para mellorar a situación, tente desactivar a súa pantalla compartida.",
    "Disable screenshare" : "Desactivar a pantalla compartida",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Ou a súa conexión a Internet ou o seu computador están ocupados e é posíbel que outros participantes non sexan quen de entendelo nin velo. Para mellorar a situación, tente desactivar o esvaemento do fondo ou do seu vídeo.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Ou a súa conexión a internet ou o computador están ocupados e pode que outros participantes non sexan quen de entendelo e velo. Para mellorar a situación, tente desactivar o seu vídeo.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Ou a súa conexión a internet ou o computador están ocupados e pode que outros participantes non sexan quen de entendelo.",
    "Screen sharing is not supported by your browser." : "O navegador non admite a compartición de pantalla.",
    "Screen sharing requires the page to be loaded through HTTPS." : "A compartición de pantalla precisa que a páxina sexa cargada a través de HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Screensharing precisa que a páxina sexa cargada a través de HTTPS.",
    "An error occurred while starting screensharing." : "Produciuse un erro ao iniciar a compartición da pantalla.",
    "Select virtual background" : "Seleccione o fondo virtual",
    "Show your screen" : "Amosar a súa pantalla",
    "Stop screensharing" : "Deixar de compartir a pantalla",
    "Mute others" : "Silenciar aos outros",
    "Start recording" : "Comezar a gravar",
    "Set up breakout rooms" : "Preparar as salas parciais",
    "Download attendance list" : "Descargar lista de asistencia",
    "Open Calendar" : "Abre o calendario",
    "Remove participant {name}" : "Retirar o participante {name}",
    "Would you like to delete this conversation?" : "Quere eliminar esta conversa?",
    "Are you sure you want to delete this conversation?" : "Confirma que quere eliminar esta conversa?",
    "Delete now" : "Eliminar agora",
    "Keep" : "Conservar",
    "Open dialpad" : "Abrir o dial de marcación",
    "Select a region" : "Seleccione unha rexión",
    "Local time: {time}" : "Hora local: {time}",
    "Scheduled {datetime}" : "Programada o/ás {datetime}",
    "Scheduled for {datetime}" : "Programada para {datetime}",
    "Search …" : "Buscar…",
    "Message without mention" : "Mensaxe sen mención",
    "Mention myself" : "Mencioname",
    "Mention everyone" : "Mencionar a todos",
    "Select a conversation" : "Seleccionar unha conversa",
    "Select a mode" : "Seleccionar un modo",
    "You do not have permissions to access this conversation." : "Vde. non ten permiso para acceder a esta conversa.",
    "Join a different conversation or start a new one." : "Únase a outra conversa ou inicie unha nova.",
    "The conversation does not exist" : "Non existe a conversa",
    "Join a conversation or start a new one!" : "Únase a unha conversa ou inicie unha nova!",
    "Duplicate session" : "Sesión duplicada",
    "Creating and joining a conversation with \"{userid}\"" : "Crear e unirse a unha conversa con «{userid}»",
    "Join a conversation or start a new one" : "Únase a unha conversa ou inicie unha nova",
    "Error while joining the conversation" : "Produciuse un erro ao unirse á conversa",
    "Another user" : "Outro usuario",
    "Nextcloud URL" : "URL de Nextcloud",
    "Nextcloud user" : "Usuario de Nextcloud",
    "User password" : "Contrasinal do usuario",
    "Talk conversation" : "Conversa no Parladoiro",
    "Skip TLS verification" : "Omitir a verificación TLS",
    "Matrix server URL" : "URL do servidor Matrix",
    "User" : "Usuario",
    "Matrix channel" : "Canle do Matrix",
    "Mattermost server URL" : "URL do servidor Mattermost",
    "Mattermost user" : "Usuario de  Mattermost",
    "Team name" : "Nome do equipo",
    "Channel name" : "Nome da canle",
    "Rocket.Chat server URL" : "URL do servidor Rocket.Chat",
    "User name or email address" : "Nome de usuario ou enderezo de correo-e",
    "Rocket.Chat channel" : "Canle do Rocket.Chat",
    "Zulip server URL" : "URL do servidor Zulip",
    "Bot user name" : "Nome de usuario do bot",
    "Bot API key" : "Chave da API do bot",
    "Zulip channel" : "Canle do Zulip",
    "API token" : "Testemuño da API",
    "Slack channel" : "Canle do Slack",
    "Server ID or name" : "ID ou nome do servidor",
    "Channel ID (prefixed with \"ID:\") or name" : "ID da canle (co prefixo «ID:») ou nome",
    "Channel" : "Canle",
    "Login" : "Acceder",
    "Chat ID" : "ID da parola",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL do servidor IRC (p. ex., chat.freenode.net:6667)",
    "Nickname" : "Alcume",
    "Connection password" : "Contrasinal de conexión",
    "IRC channel" : "Canle do IRC",
    "Channel password" : "Contrasinal da canle",
    "NickServ nickname" : "Alcume NickServ",
    "NickServ password" : "Contrasinal de NickServ",
    "Use TLS" : "Usar TLS",
    "Use SASL" : "Usar SASL",
    "Tenant ID" : "ID do cesionario",
    "Client ID" : "ID de cliente",
    "Team ID" : "ID do equipo",
    "Thread ID" : "ID do fío",
    "XMPP/Jabber server URL" : "URL do servidor XMPP/Jabber",
    "MUC server URL" : "URL do servidor MUC",
    "Jabber ID" : "ID do Jabber",
    "Pinned messages" : "Mensaxes fixadas",
    "Media" : "Multimedia",
    "Polls" : "Enquisas",
    "Deck cards" : "Tarxetas de Gabeta",
    "Voice messages" : "Mensaxes de voz",
    "Locations" : "Localizacións",
    "Call recordings" : "Gravacións de chamadas",
    "Audio" : "Son",
    "Show all pinned messages" : "Amosar todas as mensaxes fixadas",
    "Show all media" : "Amosar todos os medios",
    "Show all files" : "Amosar todos os ficheiros",
    "Show all polls" : "Amosar todas as enquisas",
    "Show all deck cards" : "Amosar todas as tarxetas da Gabeta",
    "Show all voice messages" : "Amosar todas as mensaxes de voz",
    "Show all locations" : "Amosar todas as localizacións",
    "Show all call recordings" : "Amosar todas as gravacións de chamadas",
    "Show all audio" : "Amosar todo o son",
    "Show all other" : "Amosar todos os demais",
    "Follow conversation settings" : "Seguir os axustes da conversa",
    "Group" : "Grupo",
    "Team" : "Equipo",
    "You reconnected to the call" : "Vde. volveu conectarse á chamada",
    "{actor} reconnected to the call" : "{actor} volveu conectarse á chamada",
    "You added {user0} and {user1}" : "Vde. engadiu a {user0} e a {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Vde. engadiu a {user0}, a {user1} e a %n participante máis","Vde. engadiu a {user0}, a {user1} e a %n participantes máis"],
    "An administrator added you and {user0}" : "Alguén da administración do sitio engadiuno a Vde. e a {user0}",
    "{actor} added you and {user0}" : "{actor} engadiuno a Vde. e a {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Alguén da administración do sitio engadiuno a Vde., a {user0} e a %n participante máis","Alguén da administración do sitio engadiuno a Vde., a {user0} e a %n participantes máis"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} engadiuno a Vde., a {user0} e a %n participante máis","{actor} engadiuno a Vde., a {user0} e a %n participantes máis"],
    "An administrator added {user0} and {user1}" : "Alguén da administración do sitio engadiu a {user0} e a {user1}",
    "{actor} added {user0} and {user1}" : "{actor} engadiu a {user0} e a {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Alguén da administración do sitio engadiu a {user0}, a {user1} e a %n participante máis","Alguén da administración do sitio engadiu a {user0}, a {user1} e a %n participantes máis"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} engadiu a {user0}, a {user1} e a %n participante máis","{actor} engadiu a {user0}, a {user1} e a %n participantes máis"],
    "You removed {user0} and {user1}" : "Vde. retirou a {user0} e a {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Vde. retirou a {user0}, a {user1} e a %n participante máis","Vde. retirou a {user0}, a {user1} e a %n participantes máis"],
    "An administrator removed you and {user0}" : "Alguén da administración retirouno a Vde. e a {user0}",
    "{actor} removed you and {user0}" : "{actor} retirouno a Vde. e a {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Alguén da administración do sitio retirouno a Vde., a {user0} e a %n participante máis","Alguén da administración do sitio retirouno a Vde., a {user0} e a %n participantes máis"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} retirouno a Vde., a {user0} e a %n participante máis","{actor} retirouno a Vde., a {user0} e a %n participantes máis"],
    "An administrator removed {user0} and {user1}" : "Alguén da administración retirou a {user0} e a {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} retirou a {user0} e a {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Alguén da administración do sitio retirou a {user0}, a {user1} e a %n participante máis","Alguén da administración do sitio retirou a {user0}, a {user1} e a %n participantes máis"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} retirou a {user0}, a {user1} e a %n participante máis","{actor} retirou a {user0}, a {user1} e a %n participantes máis"],
    "You and {user0} joined the call" : "Vde. e {user0} uníronse á chamada",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Vde., {user0} e %n participante máis uníronse á chamada","Vde., {user0} e %n participantes máis uníronse á chamada"],
    "{user0} and {user1} joined the call" : "{user0} e {user1} uníronse á chamada",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} e %n participante máis uníronse á chamada","{user0}, {user1} e %n máis participantes uníronse á chamada"],
    "You and {user0} left the call" : "Vde. e {user0} deixaron á chamada",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Vde., {user0} e %n participante máis deixaron á chamada","Vde., {user0} e %n participantes máis deixaron á chamada"],
    "{user0} and {user1} left the call" : "{user0} e {user1} deixaron á chamada",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} e %n participante máis deixaron á chamada","{user0}, {user1} e %n máis participantes deixaron á chamada"],
    "You promoted {user0} and {user1} to moderators" : "Vde. promoveu a {user0} e a {user1} a moderadores",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Vde. promoveu a {user0}, a {user1} e a %n participante máis a moderadores","Vde. promoveu a {user0}, a {user1} e a %n participantes máis a moderadores"],
    "An administrator promoted you and {user0} to moderators" : "Alguén da administración do sitio promoveuno a Vde. e a {user0} a moderadores",
    "{actor} promoted you and {user0} to moderators" : "{actor} promoveuno a Vde. e a {user0} a moderadores",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Alguén da administración do sitio promoveu a Vde., a {user0} e a %n participante máis a moderadores","Alguén da administración do sitio promoveu a Vde., a {user0} e a %n participantes máis a moderadores"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} promoveu a Vde., a {user0} e a %n participante máis a moderadores","{actor} promoveu a Vde., a {user0} e a %n participantes máis a moderadores"],
    "An administrator promoted {user0} and {user1} to moderators" : "Alguén da administración do sitio promoveuno a {user0} e a {user1} a moderadores",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} promoveu a {user0} e a {user1} a moderadores",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Alguén da administración do sitio promoveu a {user0}, a {user1} e a %n participante máis a moderadores","Alguén da administración do sitio promoveu a {user0}, a {user1} e a %n participantes máis a moderadores"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} promoveu a {user0}, a {user1} e a %n participante máis a moderadores","{actor} promoveu a {user0}, a {user1} e a %n participantes máis a moderadores"],
    "You demoted {user0} and {user1} from moderators" : "Vde. relegou a {user0} e {user1} dos moderadores",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Vde. relegou a {user0}, a {user1} e a %n participante máis dos moderadores","Vde. relegou a {user0}, a {user1} e a %n participantes máis dos moderadores"],
    "An administrator demoted you and {user0} from moderators" : "Alguén da administración do sitio relegouno a Vde. e a {user0} dos moderadores",
    "{actor} demoted you and {user0} from moderators" : "{actor} relegouno a Vde. e a {user0} dos moderadores",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Alguén da administración do sitio relegouno a Vde., a {user0} e a %n participante máis dos moderadores","Alguén da administración do sitio relegouno a Vde., a {user0} e a %n participantes máis dos moderadores"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} relegouno a Vde., a {user0} e a %n participante máis dos moderadores","{actor} relegouno a Vde., a {user0} e a %n participantes máis dos moderadores"],
    "An administrator demoted {user0} and {user1} from moderators" : "Alguén da administración do sitio relegou a {user0} e a {user1} de moderadores",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} relegou a {user0} e {user1} dos moderadores",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Alguén da administración do sitio relegou a {user0}, a {user1} e a %n participante máis dos moderadores","Alguén da administración do sitio relegou a {user0}, a {user1} e a %n participantes máis dos moderadores"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} relegou a {user0}, a {user1} e a %n participante máis dos moderadores","{actor} relegou a {user0}, a {user1} e a %n participantes máis dos moderadores"],
    "You:" : "Vde.:",
    "You: {lastMessage}" : "Vde.: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(editado por Vde.)",
    "(edited by a deleted user)" : "(editado por un usuario eliminado)",
    "(edited by {moderator})" : "(editado por {moderator})",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Está a tentar unirse a unha conversa mentres ten unha sesión activa noutra xanela ou dispositivo. Isto non é compatíbel  actualmente con Parladoiro de Nextcloud. Que quere facer?",
    "Leave this page" : "Abandonar esta páxina",
    "Join here" : "Únase aquí",
    "Deck card has been posted to {conversation}" : "A tarxeta de Gabeta foi publicada en {conversation}",
    "An error occurred while posting deck card to conversation" : "Produciuse un erro ao publicar a tarxeta na conversa",
    "Post to a conversation" : "Publicar nunha conversa",
    "Post to conversation" : "Publicar na conversa",
    "The recording failed. Please contact your administrator." : "Produciuse un fallo de gravación. Póñase en contacto coa administración desta instancia.",
    "Location has been posted to {conversation}" : "A localización publicouse en {conversation}",
    "An error occurred while posting location to conversation" : "Produciuse un erro ao publicar a localización na conversa.",
    "Share to a conversation" : "Compartir nunha conversa",
    "Share to conversation" : "Compartir na conversa",
    "In conversation" : "Na conversa",
    "Search in conversation: {conversation}" : "Buscar na conversa: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "As súas solicitudes están limitadas polo momento por mor da protección da forza bruta",
    "Error while clearing conversation history" : "Produciuse un erro ao limpar o historial da conversa",
    "Error occurred while allowing guests" : "Produciuse un erro ao permitir convidados",
    "Error occurred while disallowing guests" : "Produciuse un erro ao deixar de permitir convidados",
    "Error occurred when restricting the conversation to moderator" : "Produciuse un erro ao restrinxir a conversa ao moderador",
    "Error occurred when opening the conversation to everyone" : "Produciuse un erro ao abrir a conversa a todos",
    "Conversation password has been saved" : "Gardouse o contrasinal da conversa",
    "Conversation password has been removed" : "Retirouse o contrasinal de conversa",
    "Error occurred while saving conversation password" : "Produciuse un erro ao gardar o contrasinal da conversa",
    "Call recording is starting." : "A gravación de chamadas está comezando.",
    "Call recording stopped while starting." : "A gravación de chamadas detívose ao iniciarse.",
    "Call recording stopped. You will be notified once the recording is available." : "Detívose a gravación da chamada. Recibirá unha notificación cando a gravación estea dispoñíbel.",
    "Conversation picture set" : "Definiuse a imaxe da conversa",
    "Conversation picture deleted" : "Eliminouse a imaxe da conversa",
    "Could not delete the conversation picture" : "Non foi posíbel eliminar a imaxe da conversa",
    "Could not remove the automatic expiration" : "Non foi posíbel retirarlle a caducidade automática",
    "Could not post message: {errorMessage}" : "Non foi posíbel publicar a mensaxe: {errorMessage}",
    "Participant is banned successfully" : "O participante foi expulsado correctamente",
    "Error while banning the participant" : "Produciuse un erro ao expulsar o participante",
    "An error occurred while fetching the participants" : "Produciuse un erro ao recuperar os participantes",
    "Could not send invitation to {actorId}" : "Non foi posíbel enviar o convite a {actorId}",
    "Invitations sent" : "Convites enviados",
    "Error occurred when sending invitations" : "Produciuse un erro ao enviar os convites",
    "Failed to join the conversation." : "Produciuse un fallo ao unirse á conversa.",
    "An error occurred while creating breakout rooms" : "Produciuse un erro ao crear as salas parciais",
    "An error occurred while re-ordering the attendees" : "Produciuse un erro ao reordenar os asistentes",
    "An error occurred while deleting breakout rooms" : "Produciuse un erro ao eliminar as salas parciais",
    "An error occurred while starting breakout rooms" : "Produciuse un erro ao iniciar as salas parciais",
    "An error occurred while stopping breakout rooms" : "Produciuse un erro ao deter as salas parciais",
    "An error occurred while sending a message to the breakout rooms" : "Produciuse un erro ao enviar unha mensaxe ás salas parciais",
    "An error occurred while requesting assistance" : "Produciuse un erro ao solicitar asistencia",
    "An error occurred while resetting the request for assistance" : "Produciuse un erro ao restabelecer a solicitude de asistencia",
    "An error occurred while joining breakout room" : "Produciuse un erro ao entrar na sala parcial",
    "Failed to rename the thread" : "Produciuse un fallo ao cambiarlle o nome ao fío",
    "Error fetching upcoming events" : "Produciuse un erro ao recuperar os próximos eventos",
    "Error fetching upcoming reminders" : "Produciuse un erro ao recuperar os próximos lembretes",
    "An error occurred while accepting an invitation" : "Produciuse un erro ao aceptar un convite",
    "An error occurred while rejecting an invitation" : "Produciuse un erro ao rexeitar un convite",
    "{guest} (guest)" : "{guest} (convidado)",
    "Poll draft has been saved" : "Gardouse o borrador da enquisa",
    "An error occurred while saving the draft" : "Produciuse un erro ao gardar o borrador",
    "An error occurred while submitting your vote" : "Produciuse un erro ao enviar o seu voto",
    "An error occurred while ending the poll" : "Produciuse un erro ao finalizar a enquisa",
    "An error occurred while deleting the poll draft" : "Produciuse un erro ao eliminar o borrador da enquisa",
    "Poll \"{name}\" was created by {user}. Click to vote" : "A enquisa «{name}» foi creada por {user}. Prema para votar",
    "Failed to add reaction" : "Produciuse un fallo ao engadir a reacción",
    "Failed to remove reaction" : "Produciuse un fallo ao retirar a reacción",
    "Error while uploading file \"{fileName}\"" : "Produciuse un erro ao enviar o ficheiro «{fileName}».",
    "Not enough free space to upload file \"{fileName}\"" : "Non hai espazo libre abondo para enviar o ficheiro «{fileName}»",
    "You are not allowed to share files" : "Vde. non ten permiso para compartir ficheiros",
    "Error while sharing file" : "Produciuse un erro ao compartir o ficheiro",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Parladoiro de Nextcloud non é totalmente compatíbel co navegador que está a usar. Utilice a versión máis recente de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera ou Apple Safari.",
    "_In %n hour_::_In %n hours_" : ["En %n hora","En %n horas"],
    "_%n minute _::_%n minutes_" : ["%n minuto","%n minutos"],
    "In {hours} and {minutes}" : "En {hours} e {minutes}",
    "_In %n minute_::_In %n minutes_" : ["En %n minuto","En %n minutos"],
    "Later today – {timeLocale}" : "Hoxe máis tarde – {timeLocale}",
    "Set time for later today" : "Definir a hora para hoxe máis tarde",
    "Tomorrow – {timeLocale}" : "Mañá – {timeLocale}",
    "Set time for tomorrow" : "Definir a hora para mañá",
    "This weekend – {timeLocale}" : "Esta semana – {timeLocale}",
    "Set time for this weekend" : "Definir a hora para este fin de semana",
    "Next week – {timeLocale}" : "Semana seguinte – {timeLocale}",
    "Set time for next week" : "Definir a hora para a semana seguinte",
    "Message link copied to clipboard" : "A ligazón da mensaxe foi copiada no portapapeis",
    "Conversation link copied to clipboard" : "A ligazón da conversa foi copiada no portapapeis",
    "The link could not be copied" : "Non foi posíbel copiar a ligazón.",
    "Error while parsing a PROPFIND error" : "Produciuse un erro ao analizar un erro PROPFIND",
    "Sending signaling message has failed" : "Produciuse un fallo no envío da mensaxe de sinalización",
    "Lost connection to signaling server. Trying to reconnect." : "Perdeuse a conexión co servidor de sinalización. Tentando volver conectar.",
    "Lost connection to signaling server." : "Perdeuse a conexión co servidor de sinalización.",
    "Connecting is taking longer than expected …" : "A conexión está a levar máis tempo do agardado…",
    "Failed to connect. Retrying …" : "Produciuse un fallo ao conectar. Tentándoo de novo…",
    "Failed to connect. The signaling server may be set up incorrectly" : "Produciuse un fallo ao conectar O servidor de sinalización pode estar configurado incorrectamente",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "O servidor de sinalización configurado debe ser actualizado para ser compatíbel con esta versión de Parladoiro. Póñase en contacto coa súa administración.",
    "Please restart the app." : "Reinicie a aplicación",
    "Please reload the page." : "Volva cargar a páxina.",
    "Please try to restart the app." : "Tente reiniciar a aplicación.",
    "Please try to reload the page." : "Tente volver cargar a páxina.",
    "Do not disturb" : "Non molestar",
    "Away" : "Ausente",
    "Microphone {number}" : "Micrófono {number}",
    "Camera {number}" : "Cámara {number}",
    "Speaker {number}" : "Relator {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Semella que está a falar mentres esta silenciado, desactive o silencio para que os demais o escoiten",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Non foi posíbel definir unha conexión con polo menos un participante. Pode ser necesario un servidor TURN para o seu escenario. Pídalle á administración do seu Nextcloud que configure un segundo {linkstart}esta documentación{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Isto está levando máis tempo do esperado. Os permisos dos multimedia xa están concedidos (ou rexeitados)? En caso afirmativo, reinicie o navegador, xa que o son e o vídeo están fallando",
    "Access to microphone & camera is only possible with HTTPS" : "O acceso ao micrófono e a cámara só é posíbel con HTTPS",
    "Please move your setup to HTTPS" : "Cambie a súa configuración a HTTPS",
    "Access to microphone & camera was denied" : "Foi denegado o acceso ao micrófono e a cámara",
    "WebRTC is not supported in your browser" : "O seu navegador non admite WebRTC",
    "Please use a different browser like Firefox or Chrome" : "Use un navegador diferente como Firefox ou Chrome",
    "Error while accessing microphone & camera" : "Produciuse un erro ao acceder ao micrófono e á cámara",
    "%s Talk on your mobile devices" : "Parladoiro de %s nos seus dispositivos móbiles",
    "Join conversations at any time, anywhere, on any device." : "Únase a conversas en calquera momento, en calquera lugar, con calquera dispositivo.",
    "Android app" : "Aplicación de Android",
    "iOS app" : "Aplicación de iOS",
    "__language_name__" : "Galego",
    "Webhook Demo" : "Demostración do punto de ancoraxe web",
    "Call summary (%s)" : "Resumo da chamada (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "O bot de resumo de chamadas publica unha mensaxe de resumo após a chamada coa lista de todos os participantes e describindo as tarefas",
    "Tasks" : "Tarefas",
    "Notes" : "Notas",
    "Reports" : "Informes",
    "Decisions" : "Decisións",
    "Agenda" : "Axenda",
    "Call summary" : "Resumo da chamada",
    "Call summary - {title}" : "Resumo da chamada — {title}",
    "Talk conversation for event" : "Conversa en Parladoiro para o evento",
    "Client Push is installed, this improves the performance of desktop clients." : "A notificación automática ao cliente está instalada, isto mellora o rendemento dos clientes de escritorio.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} non está instalada, isto pode levar a problemas de rendemento ao usar clientes de escritorio.",
    "Next meeting" : "Seguinte xuntanza",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Programe unha xuntanza desde o seu calendario. Debe definir unha conversa de Parladoiro como ubicación para que sexa amosada aquí",
    "Join conversations from remote Nextcloud servers" : "Únase a conversas desde servidores remotos de Nextcloud",
    "Your default media state has been saved" : "Gardouse o seu estado multimedia predeterminado",
    "Set reminder for later today" : "Definir un lembrete para hoxe máis tarde",
    "Set reminder for tomorrow" : "Definir un lembrete para mañá",
    "Set reminder for this weekend" : "Definir un lembrete para este fin de semana",
    "Set reminder for next week" : "Definir un lembrete para a seguinte semana",
    "Generate summary" : "Xerar un resumo",
    "Open poll • You voted already" : "Enquisa aberta • Vde. xa votou",
    "Open poll • Click to vote" : "Enquisa aberta • Prema para votar",
    "Poll • Ended" : "Enquisa • Finalizada",
    "Talk recording from {time} ({conversation})" : "Gravación da conversa desde {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Resultados da enquisa • %n voto","Resultados da enquisa • %n votos"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Enquisa aberta • %n voto","Enquisa aberta • %n votos"],
    "Submit vote" : "Enviar o voto",
    "Your privacy setting has been saved" : "Gardouse o seu axuste de privacidade",
    "Your personal setting has been saved" : "Gardouse o seu axuste persoal",
    "Failed to save sounds setting" : "Produciuse un fallo ao gardar os axustes de son",
    "Sounds setting saved" : "Gardáronse os axustes de son",
    "Always shown if recording consent is required" : "Amosar sempre se é necesario o consentimento da gravación",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Parladoiro de Nextcloud foi actualizada, non pode comezar nin unirse a unha chamada.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Uniuse á conversa noutra xanela ou dispositivo. Isto non é compatíbel actualmente con Parladoiro de Nextcloud polo que esta sesión pechouse.",
    "Nextcloud Talk was updated." : "Parladoiro de Nextcloud foi actualizada",
    "Nextcloud is in maintenance mode." : "Nextcloud está en modo de mantemento.",
    "Nextcloud Talk Federation was updated." : "Foi actualizada a federación de Parladoiro de Nextcloud",
    "Enable live translation" : "Activar a tradución en directo",
    "I picked list style" : "Escollín o estilo de lista",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Ei! Estás a usar Parladoiro en formato de lista ou con globos de mensaxe?"
},
"nplurals=2; plural=(n != 1);");
